pub struct LlmEventSummarizer { /* private fields */ }Available on crate feature
agents only.Expand description
An LLM-based event summarizer for sliding window compaction.
When called with a list of events, this formats the events, generates a
summary using an LLM, and returns a new Event containing the summary
within an EventCompaction.
Implementations
Sourceimpl LlmEventSummarizer
impl LlmEventSummarizer
Sourcepub fn new(llm: Arc<dyn Llm>) -> LlmEventSummarizer
pub fn new(llm: Arc<dyn Llm>) -> LlmEventSummarizer
Create a new summarizer using the given LLM.
Sourcepub fn with_prompt_template(
self,
template: impl Into<String>,
) -> LlmEventSummarizer
pub fn with_prompt_template( self, template: impl Into<String>, ) -> LlmEventSummarizer
Create a new summarizer with a custom prompt template.
The template must contain {conversation_history} as a placeholder.