pub struct TeamMemberSpec {
pub name: String,
pub description: Option<String>,
pub required_capabilities: Vec<String>,
pub registry: TeamRegistryRequirement,
}Available on crate feature
agents only.Expand description
Serializable metadata for one team member.
Fields
name: StringName used to bind the member to an Agent.
description: Option<String>Optional portable description for design tools and documentation.
required_capabilities: Vec<String>Capabilities a discovered binding must provide.
registry: TeamRegistryRequirementRegistry trust, version, and integrity constraints for this member.
Implementations
Sourceimpl TeamMemberSpec
impl TeamMemberSpec
Sourcepub fn new(name: impl Into<String>) -> TeamMemberSpec
pub fn new(name: impl Into<String>) -> TeamMemberSpec
Creates member metadata for name.
Sourcepub fn with_description(self, description: impl Into<String>) -> TeamMemberSpec
pub fn with_description(self, description: impl Into<String>) -> TeamMemberSpec
Adds a portable description.
Sourcepub fn with_capabilities(
self,
capabilities: impl IntoIterator<Item = impl Into<String>>,
) -> TeamMemberSpec
pub fn with_capabilities( self, capabilities: impl IntoIterator<Item = impl Into<String>>, ) -> TeamMemberSpec
Requires all named capabilities when resolving this member dynamically.
Sourcepub fn with_registry_requirement(
self,
requirement: TeamRegistryRequirement,
) -> TeamMemberSpec
pub fn with_registry_requirement( self, requirement: TeamRegistryRequirement, ) -> TeamMemberSpec
Applies discovery-time trust and integrity constraints.