pub enum ContentBlockDelta {
TextDelta(TextDelta),
InputJsonDelta(InputJsonDelta),
CitationsDelta(CitationsDelta),
ThinkingDelta(ThinkingDelta),
SignatureDelta(SignatureDelta),
}Available on crate feature
anthropic-client only.Expand description
A raw content block delta, representing a streaming update to a content block.
This type is used for streaming responses from the API, where content blocks are updated incrementally.
Variants
TextDelta(TextDelta)
A text delta.
InputJsonDelta(InputJsonDelta)
An input JSON delta.
CitationsDelta(CitationsDelta)
A citations delta.
ThinkingDelta(ThinkingDelta)
A thinking delta.
SignatureDelta(SignatureDelta)
A signature delta.
Implementations
Sourceimpl ContentBlockDelta
impl ContentBlockDelta
Sourcepub fn from_text_delta(text_delta: TextDelta) -> ContentBlockDelta
pub fn from_text_delta(text_delta: TextDelta) -> ContentBlockDelta
Create a new ContentBlockDelta from a text delta.
Sourcepub fn from_input_json_delta(
input_json_delta: InputJsonDelta,
) -> ContentBlockDelta
pub fn from_input_json_delta( input_json_delta: InputJsonDelta, ) -> ContentBlockDelta
Create a new ContentBlockDelta from an input JSON delta.
Sourcepub fn from_citations_delta(
citations_delta: CitationsDelta,
) -> ContentBlockDelta
pub fn from_citations_delta( citations_delta: CitationsDelta, ) -> ContentBlockDelta
Create a new ContentBlockDelta from a citations delta.
Sourcepub fn from_thinking_delta(thinking_delta: ThinkingDelta) -> ContentBlockDelta
pub fn from_thinking_delta(thinking_delta: ThinkingDelta) -> ContentBlockDelta
Create a new ContentBlockDelta from a thinking delta.
Sourcepub fn from_signature_delta(
signature_delta: SignatureDelta,
) -> ContentBlockDelta
pub fn from_signature_delta( signature_delta: SignatureDelta, ) -> ContentBlockDelta
Create a new ContentBlockDelta from a signature delta.