pub enum MessageParamContent {
String(String),
Array(Vec<ContentBlock>),
}Available on crate feature
anthropic-client only.Expand description
The content of a message, which can be either a string or an array of content blocks.
Variants