#[non_exhaustive]pub enum ServerFallbackContentBlock {
Fallback(FallbackContentBlock),
Standard(ContentBlock),
Unknown(Value),
}Available on crate feature
anthropic-client only.Expand description
Content returned by a server-side fallback request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fallback(FallbackContentBlock)
A handoff marker emitted when the API changes models.
Standard(ContentBlock)
Any standard Anthropic message content block.
Unknown(Value)
A response block not yet represented by this crate.
Keeping the raw value prevents fallback responses from becoming unreadable when the API introduces a new content block.