StopReason

Enum StopReason 

pub enum StopReason {
    EndTurn,
    MaxTokens,
    StopSequence,
    ToolUse,
    PauseTurn,
    Refusal,
    PauseRun,
    ModelContextWindowExceeded,
}
Available on crate feature anthropic-client only.
Reasons why the model stopped generating a response.

Variants



EndTurn

The model reached the end of a generated turn



MaxTokens

The response reached the maximum token limit for the response



StopSequence

The model reached a specified stop sequence



ToolUse

The model indicated it wants to use a tool



PauseTurn

The model paused in the middle of a turn



Refusal

The model refused to respond due to safety or other considerations



PauseRun

The run was paused (e.g. for human-in-the-loop approval)



ModelContextWindowExceeded

The model’s context window was exceeded