pub enum ToolResultBlockContent {
String(String),
Array(Vec<Content>),
}Available on crate feature
anthropic-client only.Expand description
The content of a tool result block, which can be either a string or an array of content items.
Variants