pub enum WebSearchToolResultBlockContent {
Results(Vec<WebSearchResultBlock>),
Error(WebSearchToolResultError),
}Available on crate feature
anthropic-client only.Expand description
Content of a web search tool result.
This can either be a list of search results or an error.
Variants
Results(Vec<WebSearchResultBlock>)
A list of web search results.
Error(WebSearchToolResultError)
An error that occurred during the web search.
Implementations
Sourceimpl WebSearchToolResultBlockContent
impl WebSearchToolResultBlockContent
Sourcepub fn with_results(
results: Vec<WebSearchResultBlock>,
) -> WebSearchToolResultBlockContent
pub fn with_results( results: Vec<WebSearchResultBlock>, ) -> WebSearchToolResultBlockContent
Creates a new WebSearchToolResultBlockContent with the specified results.
Sourcepub fn with_error(
error: WebSearchToolResultError,
) -> WebSearchToolResultBlockContent
pub fn with_error( error: WebSearchToolResultError, ) -> WebSearchToolResultBlockContent
Creates a new WebSearchToolResultBlockContent with the specified error.
Sourcepub fn is_results(&self) -> bool
pub fn is_results(&self) -> bool
Returns true if the content is a list of results.
Sourcepub fn as_results(&self) -> Option<&Vec<WebSearchResultBlock>>
pub fn as_results(&self) -> Option<&Vec<WebSearchResultBlock>>
Returns a reference to the results if this is a Results variant, or None otherwise.
Sourcepub fn as_error(&self) -> Option<&WebSearchToolResultError>
pub fn as_error(&self) -> Option<&WebSearchToolResultError>
Returns a reference to the error if this is an Error variant, or None otherwise.
Sourcepub fn result_count(&self) -> usize
pub fn result_count(&self) -> usize
Returns the number of results if this is a Results variant, or 0 if this is an Error variant.