pub struct CitationContentBlockLocation {
pub cited_text: String,
pub document_index: i32,
pub document_title: Option<String>,
pub end_block_index: i32,
pub start_block_index: i32,
}Available on crate feature
anthropic-client only.Expand description
Represents a content block-based location citation.
This type is used to indicate a specific span of content blocks in a document.
Fields
cited_text: StringThe text that was cited
document_index: i32The index of the document in the input context
document_title: Option<String>Optional title of the document
end_block_index: i32The end content block index (exclusive) of the citation in the document
start_block_index: i32The start content block index (inclusive) of the citation in the document
Implementations
Sourceimpl CitationContentBlockLocation
impl CitationContentBlockLocation
Sourcepub fn new(
cited_text: String,
document_index: i32,
start_block_index: i32,
end_block_index: i32,
document_title: Option<String>,
) -> CitationContentBlockLocation
pub fn new( cited_text: String, document_index: i32, start_block_index: i32, end_block_index: i32, document_title: Option<String>, ) -> CitationContentBlockLocation
Creates a new CitationContentBlockLocation
Sourcepub fn block_count(&self) -> i32
pub fn block_count(&self) -> i32
Returns the number of content blocks in the citation span