pub struct CitationsConfig {
pub enabled: bool,
}Available on crate feature
anthropic-client only.Expand description
Configuration for enabling or disabling citations in the response.
This type allows controlling whether citations will be included in the model’s response.
Fields
enabled: boolWhether citations are enabled
Implementations
Sourceimpl CitationsConfig
impl CitationsConfig
Sourcepub fn new(enabled: bool) -> CitationsConfig
pub fn new(enabled: bool) -> CitationsConfig
Creates a new CitationsConfig with the specified enabled state
Sourcepub fn enabled() -> CitationsConfig
pub fn enabled() -> CitationsConfig
Returns a CitationsConfig with citations enabled
Sourcepub fn disabled() -> CitationsConfig
pub fn disabled() -> CitationsConfig
Returns a CitationsConfig with citations disabled