pub struct ContentBlockSourceParam {
pub content: ContentBlockSourceContent,
}Available on crate feature
anthropic-client only.Expand description
Parameter for a content block source.
Fields
content: ContentBlockSourceContentThe content of the source, which can be either a string or an array of content items.
Implementations
Sourceimpl ContentBlockSourceParam
impl ContentBlockSourceParam
Sourcepub fn new_with_string(content: String) -> ContentBlockSourceParam
pub fn new_with_string(content: String) -> ContentBlockSourceParam
Create a new ContentBlockSourceParam with a string content.
Sourcepub fn from_string_ref(content: &str) -> ContentBlockSourceParam
pub fn from_string_ref(content: &str) -> ContentBlockSourceParam
Create a new ContentBlockSourceParam with string content from a str reference.
Sourcepub fn new_with_array(content: Vec<Content>) -> ContentBlockSourceParam
pub fn new_with_array(content: Vec<Content>) -> ContentBlockSourceParam
Create a new ContentBlockSourceParam with an array of content items.
Sourcepub fn new_with_item(content: Content) -> ContentBlockSourceParam
pub fn new_with_item(content: Content) -> ContentBlockSourceParam
Create a new ContentBlockSourceParam with a single content item.