pub struct ContentBlockStopEvent {
pub index: usize,
}Available on crate feature
anthropic-client only.Expand description
An event that represents the end of a content block in a streaming response.
Fields
index: usizeThe index of the content block that is ending.
Implementations
Sourceimpl ContentBlockStopEvent
impl ContentBlockStopEvent
Sourcepub fn new(index: usize) -> ContentBlockStopEvent
pub fn new(index: usize) -> ContentBlockStopEvent
Create a new ContentBlockStopEvent with the given index.