pub struct MessageDelta {
pub stop_reason: Option<StopReason>,
pub stop_sequence: Option<String>,
}Available on crate feature
anthropic-client only.Expand description
The delta information for a message delta event.
Fields
stop_reason: Option<StopReason>The reason the model stopped generating text, if it has stopped.
stop_sequence: Option<String>If the model stopped because it encountered a stop sequence, this field contains the specific stop sequence that was encountered.
Implementations
Sourceimpl MessageDelta
impl MessageDelta
Sourcepub fn new() -> MessageDelta
pub fn new() -> MessageDelta
Create a new empty MessageDelta.
Sourcepub fn with_stop_reason(self, stop_reason: StopReason) -> MessageDelta
pub fn with_stop_reason(self, stop_reason: StopReason) -> MessageDelta
Set the stop reason.
Sourcepub fn with_stop_sequence(self, stop_sequence: String) -> MessageDelta
pub fn with_stop_sequence(self, stop_sequence: String) -> MessageDelta
Set the stop sequence.