pub struct MessageDeltaUsage {
pub cache_creation_input_tokens: Option<i32>,
pub cache_read_input_tokens: Option<i32>,
pub input_tokens: Option<i32>,
pub output_tokens: i32,
pub server_tool_use: Option<ServerToolUsage>,
}Available on crate feature
anthropic-client only.Expand description
Message delta usage information.
Anthropic’s API bills and rate-limits by token counts, as tokens represent the underlying cost to their systems.
Fields
cache_creation_input_tokens: Option<i32>The cumulative number of input tokens used to create the cache entry.
cache_read_input_tokens: Option<i32>The cumulative number of input tokens read from the cache.
input_tokens: Option<i32>The cumulative number of input tokens which were used.
output_tokens: i32The cumulative number of output tokens which were used.
server_tool_use: Option<ServerToolUsage>The number of server tool requests.
Implementations
Sourceimpl MessageDeltaUsage
impl MessageDeltaUsage
Sourcepub fn new(output_tokens: i32) -> MessageDeltaUsage
pub fn new(output_tokens: i32) -> MessageDeltaUsage
Create a new MessageDeltaUsage with the given output tokens.
Sourcepub fn with_cache_creation_input_tokens(self, tokens: i32) -> MessageDeltaUsage
pub fn with_cache_creation_input_tokens(self, tokens: i32) -> MessageDeltaUsage
Set the cache creation input tokens.
Sourcepub fn with_cache_read_input_tokens(self, tokens: i32) -> MessageDeltaUsage
pub fn with_cache_read_input_tokens(self, tokens: i32) -> MessageDeltaUsage
Set the cache read input tokens.
Sourcepub fn with_input_tokens(self, tokens: i32) -> MessageDeltaUsage
pub fn with_input_tokens(self, tokens: i32) -> MessageDeltaUsage
Set the input tokens.
Sourcepub fn with_server_tool_use(
self,
server_tool_use: ServerToolUsage,
) -> MessageDeltaUsage
pub fn with_server_tool_use( self, server_tool_use: ServerToolUsage, ) -> MessageDeltaUsage
Set the server tool usage.