pub struct Metadata {
pub user_id: Option<String>,
}Available on crate feature
anthropic-client only.Expand description
Metadata that can be included with requests.
This can be used to provide additional context or client information with requests.
Fields
user_id: Option<String>An external identifier for the user who is associated with the request.
This should be a uuid, hash value, or other opaque identifier. Anthropic may use this id to help detect abuse. Do not include any identifying information such as name, email address, or phone number.
Implementations