pub struct ModelInfo {
pub id: String,
pub created_at: OffsetDateTime,
pub display_name: String,
pub type: ModelType,
}Available on crate feature
anthropic-client only.Expand description
Information about a specific model.
This struct contains details about an Anthropic model, including its unique identifier, creation time, display name, and type.
Fields
id: StringUnique model identifier.
created_at: OffsetDateTimeRFC 3339 datetime string representing the time at which the model was released.
May be set to an epoch value if the release date is unknown.
display_name: StringA human-readable name for the model.
type: ModelTypeObject type.
For Models, this is always "model".