pub struct ModelListResponse {
pub data: Vec<ModelInfo>,
pub has_more: bool,
pub first_id: Option<String>,
pub last_id: Option<String>,
}Available on crate feature
anthropic-client only.Expand description
Response from the list models API endpoint.
Contains a list of available models and pagination information.
Fields
data: Vec<ModelInfo>List of models returned by the API.
has_more: boolIndicates whether there are more results available.
If true, there are more models available that can be retrieved
by making another request with pagination parameters.
first_id: Option<String>The ID of the first object in the current page.
Can be used for pagination when requesting the previous page.
last_id: Option<String>The ID of the last object in the current page.
Can be used for pagination when requesting the next page.
Implementations