pub struct PaginatedList<T> {
pub data: Vec<T>,
pub has_more: bool,
pub first_id: Option<String>,
pub last_id: Option<String>,
}Available on crate feature
anthropic-client only.Expand description
A generic paginated list response.
Used by Models API, Files API, Skills API, and Batches API for paginated results.
Fields
data: Vec<T>The list of items in this page.
has_more: boolWhether there are more results available.
first_id: Option<String>The ID of the first item in this page (for backward pagination).
last_id: Option<String>The ID of the last item in this page (for forward pagination).
Implementations