pub struct ServerToolUseBlock {
pub id: String,
pub input: Value,
pub name: String,
pub cache_control: Option<CacheControlEphemeral>,
}Available on crate feature
anthropic-client only.Expand description
A block representing a server-side tool use request from the model.
ServerToolUseBlocks indicate the model wants to use a server-side tool (like web search).
Fields
id: StringA unique identifier for this tool use request.
input: ValueThe input data for the tool, can be any valid JSON.
name: StringThe name of the server tool being invoked. Currently only “web_search” is supported.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block.
Implementations
Sourceimpl ServerToolUseBlock
impl ServerToolUseBlock
Sourcepub fn new<S>(id: S, input: Value) -> ServerToolUseBlock
pub fn new<S>(id: S, input: Value) -> ServerToolUseBlock
Creates a new ServerToolUseBlock with the specified id and input. The name is set to “web_search” as that’s the only supported server tool.
Sourcepub fn with_cache_control(
self,
cache_control: CacheControlEphemeral,
) -> ServerToolUseBlock
pub fn with_cache_control( self, cache_control: CacheControlEphemeral, ) -> ServerToolUseBlock
Add a cache control to this server tool use block.
Sourcepub fn new_web_search<S1, S2>(id: S1, query: S2) -> ServerToolUseBlock
pub fn new_web_search<S1, S2>(id: S1, query: S2) -> ServerToolUseBlock
Creates a new web search ServerToolUseBlock with the specified id and query.