pub struct SignatureDelta {
pub signature: String,
}Available on crate feature
anthropic-client only.Expand description
A signature delta, representing a piece of a signature in a streaming response.
SignatureDelta is used in streaming responses to deliver incremental updates to a signature, typically associated with thinking blocks where the model’s reasoning process needs to be cryptographically signed.
Fields
signature: StringThe signature content.
This contains a fragment of the signature that should be appended to previously received signature fragments to build the complete signature.
Implementations
Sourceimpl SignatureDelta
impl SignatureDelta
Sourcepub fn new(signature: String) -> SignatureDelta
pub fn new(signature: String) -> SignatureDelta
Create a new SignatureDelta with the given signature.