pub struct WebSearchResultBlock {
pub encrypted_content: String,
pub page_age: Option<String>,
pub title: String,
pub url: String,
/* private fields */
}Available on crate feature
anthropic-client only.Expand description
A block containing a web search result.
WebSearchResultBlock represents a single result from a web search operation.
Fields
encrypted_content: StringEncrypted content from the web search result.
page_age: Option<String>Optional age of the page, if available.
title: StringThe title of the web page.
url: StringThe URL of the web page.
Implementations
Sourceimpl WebSearchResultBlock
impl WebSearchResultBlock
Sourcepub fn new<S1, S2, S3>(
encrypted_content: S1,
title: S2,
url: S3,
) -> WebSearchResultBlock
pub fn new<S1, S2, S3>( encrypted_content: S1, title: S2, url: S3, ) -> WebSearchResultBlock
Creates a new WebSearchResultBlock.
Sourcepub fn with_page_age(self, page_age: String) -> WebSearchResultBlock
pub fn with_page_age(self, page_age: String) -> WebSearchResultBlock
Add page age to this web search result block.