AudioProcessor

Trait AudioProcessor 

pub trait AudioProcessor: Send + Sync {
    // Required method
    fn process<'life0, 'life1, 'async_trait>(
        &'life0 self,
        frame: &'life1 AudioFrame,
    ) -> Pin<Box<dyn Future<Output = Result<AudioFrame, AudioError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait;
}
Available on crate feature audio only.
Trait for stateless or stateful DSP transforms on audio frames.

Implementors include normalizers, resamplers, noise suppressors, compressors, and the FxChain itself (enabling nested chains).

Required Methods

fn process<'life0, 'life1, 'async_trait>( &'life0 self, frame: &'life1 AudioFrame, ) -> Pin<Box<dyn Future<Output = Result<AudioFrame, AudioError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

Process a single audio frame, returning the transformed result.

Implementors