pub trait ScopeToolExt: Sized + Tool {
// Provided method
fn with_scope_guard(
self,
resolver: impl ScopeResolver + 'static,
) -> ScopedTool<Self> { ... }
}Available on crate feature
auth only.Expand description
Extension trait for easily wrapping tools with scope enforcement.
Provided Methods
Sourcefn with_scope_guard(
self,
resolver: impl ScopeResolver + 'static,
) -> ScopedTool<Self>
fn with_scope_guard( self, resolver: impl ScopeResolver + 'static, ) -> ScopedTool<Self>
Wrap this tool with scope enforcement using the given resolver.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".