Role

Struct Role 

pub struct Role {
    pub name: String,
    /* private fields */
}
Available on crate feature auth only.
A role with a set of allowed and denied permissions.

Deny rules take precedence over allow rules.

Fields

name: String

Role name (e.g., “admin”, “user”, “analyst”).

Implementations

Source

impl Role

pub fn new(name: impl Into<String>) -> Role

Create a new role with the given name.

pub fn allow(self, permission: Permission) -> Role

Allow a permission for this role.

pub fn deny(self, permission: Permission) -> Role

Deny a permission for this role.

Deny rules take precedence over allow rules.

pub fn can_access(&self, permission: &Permission) -> bool

Check if this role can access the given permission.

Returns true if the permission is allowed and not denied. Deny rules take precedence over allow rules.

pub fn allowed_permissions(&self) -> &HashSet<Permission>

Get all allowed permissions.

pub fn denied_permissions(&self) -> &HashSet<Permission>

Get all denied permissions.