pub struct Mount { /* private fields */ }code and embedded-python only.Expand description
A single mount point mapping a virtual path to a host directory.
Owns the MountMode which includes overlay state for
MountMode::OverlayMemory mounts. It can be constructed before its table
and transferred into it with MountTable::push_mount.
Implementations
Sourceimpl Mount
impl Mount
Sourcepub fn new(
virtual_path: &str,
host_path: impl AsRef<Path>,
mode: MountMode,
write_bytes_limit: Option<u64>,
) -> Result<Mount, MountError>
pub fn new( virtual_path: &str, host_path: impl AsRef<Path>, mode: MountMode, write_bytes_limit: Option<u64>, ) -> Result<Mount, MountError>
Creates a new mount point, canonicalizing the host path.
Mount memory defaults to DEFAULT_MEMORY_USAGE_LIMIT.
Errors
Returns MountError::InvalidMount if the virtual path is not absolute,
or the host path doesn’t exist or isn’t a directory.
Sourcepub fn virtual_path(&self) -> &str
pub fn virtual_path(&self) -> &str
Returns the normalized virtual path prefix for this mount.
Sourcepub fn write_bytes_limit(&self) -> Option<u64>
pub fn write_bytes_limit(&self) -> Option<u64>
Returns the optional write bytes limit for this mount.
Sourcepub fn memory_usage_limit(&self) -> u64
pub fn memory_usage_limit(&self) -> u64
Returns the aggregate mount memory budget.
Sourcepub fn with_memory_usage_limit(self, limit: u64) -> Mount
pub fn with_memory_usage_limit(self, limit: u64) -> Mount
Overrides the aggregate mount memory budget.
Sourcepub fn memory_usage(&self) -> u64
pub fn memory_usage(&self) -> u64
Returns memory currently retained by this mount’s overlay.
Sourcepub fn write_bytes_used(&self) -> u64
pub fn write_bytes_used(&self) -> u64
Returns the cumulative number of bytes written through this mount.