pub struct EventCompaction {
pub start_timestamp: DateTime<Utc>,
pub end_timestamp: DateTime<Utc>,
pub compacted_content: Content,
}Expand description
Metadata for a compacted (summarized) event. When context compaction is enabled, older events are summarized into a single compacted event containing this metadata.
Fields
start_timestamp: DateTime<Utc>Timestamp of the earliest event that was compacted.
end_timestamp: DateTime<Utc>Timestamp of the latest event that was compacted.
compacted_content: ContentThe summarized content replacing the original events.