Module interrupt

Module interrupt 

Available on crate feature graph only.
Human-in-the-loop interrupt types

Structs

GraphInterruptPayload
A graph interrupt as it crosses the Agent boundary.

Enums

Interrupt
Interrupt request from a node or configuration

Constants

INTERRUPT_METADATA_KEY
The reserved Event::provider_metadata key carrying a graph interrupt.

Functions

interrupt
Helper to create a dynamic interrupt from within a node
interrupt_with_data
Helper to create a dynamic interrupt with data