pub struct StateSchema {
pub channels: HashMap<String, Channel>,
}Available on crate feature
graph only.Expand description
State schema defines channels and their reducers
Fields
channels: HashMap<String, Channel>Channel definitions
Implementations
Sourceimpl StateSchema
impl StateSchema
Sourcepub fn new() -> StateSchema
pub fn new() -> StateSchema
Create a new empty schema
Sourcepub fn builder() -> StateSchemaBuilder
pub fn builder() -> StateSchemaBuilder
Create a schema builder
Sourcepub fn simple(channels: &[&str]) -> StateSchema
pub fn simple(channels: &[&str]) -> StateSchema
Create a simple schema with just channel names (all overwrite)
Sourcepub fn get_reducer(&self, channel: &str) -> &Reducer
pub fn get_reducer(&self, channel: &str) -> &Reducer
Get the reducer for a channel
Sourcepub fn first_undeclared<'a>(
&self,
keys: impl IntoIterator<Item = &'a str>,
) -> Option<&'a str>
pub fn first_undeclared<'a>( &self, keys: impl IntoIterator<Item = &'a str>, ) -> Option<&'a str>
Returns the first of keys that this schema does not declare.
Returns None when the schema declares no channels, because then there
is nothing to check against.
Example
use adk_graph::state::StateSchema;
let schema = StateSchema::simple(&["kept"]);
assert_eq!(schema.first_undeclared(["kept"]), None);
assert_eq!(schema.first_undeclared(["kept", "typo"]), Some("typo"));Sourcepub fn get_default(&self, channel: &str) -> Option<&Value>
pub fn get_default(&self, channel: &str) -> Option<&Value>
Get the default value for a channel
Sourcepub fn apply_update(
&self,
state: &mut HashMap<String, Value>,
key: &str,
value: Value,
)
pub fn apply_update( &self, state: &mut HashMap<String, Value>, key: &str, value: Value, )
Apply an update to state using the appropriate reducer
Sourcepub fn initialize_state(&self) -> HashMap<String, Value>
pub fn initialize_state(&self) -> HashMap<String, Value>
Initialize state with default values