pub struct ContentFilter { /* private fields */ }Available on crate feature
guardrail only.Expand description
Content filter guardrail for blocking harmful or off-topic content
Implementations
Sourceimpl ContentFilter
impl ContentFilter
Sourcepub fn new(
name: impl Into<String>,
config: ContentFilterConfig,
) -> ContentFilter
pub fn new( name: impl Into<String>, config: ContentFilterConfig, ) -> ContentFilter
Create a new content filter with custom config
Sourcepub fn harmful_content() -> ContentFilter
pub fn harmful_content() -> ContentFilter
Create a filter that blocks common harmful content patterns.
This default filter excludes developer-common terms like “hack” and “exploit”
to avoid false positives in developer contexts. Use harmful_content_strict
for the full keyword list.
Sourcepub fn harmful_content_strict() -> ContentFilter
pub fn harmful_content_strict() -> ContentFilter
Create a strict filter that blocks all harmful content patterns, including terms like “hack” and “exploit” that may produce false positives in developer contexts.
Sourcepub fn on_topic(
topic: impl Into<String>,
keywords: Vec<String>,
) -> ContentFilter
pub fn on_topic( topic: impl Into<String>, keywords: Vec<String>, ) -> ContentFilter
Create a filter that ensures content is on-topic
Sourcepub fn max_length(max: usize) -> ContentFilter
pub fn max_length(max: usize) -> ContentFilter
Create a filter with maximum length
Sourcepub fn blocked_keywords(keywords: Vec<String>) -> ContentFilter
pub fn blocked_keywords(keywords: Vec<String>) -> ContentFilter
Create a filter with blocked keywords