pub struct InvocationId(/* private fields */);Expand description
A typed wrapper around a single execution or turn identifier.
Examples
use adk_core::identity::InvocationId;
// Parse from a known value
let iid = InvocationId::try_from("inv-001").unwrap();
assert_eq!(iid.as_ref(), "inv-001");
// Or generate a new UUID-based invocation ID
let generated = InvocationId::generate();
assert!(!generated.as_ref().is_empty());Implementations
Sourceimpl InvocationId
impl InvocationId
Sourcepub fn new(value: impl Into<String>) -> Result<InvocationId, IdentityError>
pub fn new(value: impl Into<String>) -> Result<InvocationId, IdentityError>
Creates a typed identifier with validation.
Prefer this constructor at trust boundaries where the input may come from users, HTTP payloads, or external systems.
Sourcepub fn new_unchecked(value: impl Into<String>) -> InvocationId
pub fn new_unchecked(value: impl Into<String>) -> InvocationId
Sourceimpl InvocationId
impl InvocationId
Sourcepub fn generate() -> InvocationId
pub fn generate() -> InvocationId
Generates a new random invocation identifier using UUID v4.
Examples
use adk_core::identity::InvocationId;
let a = InvocationId::generate();
let b = InvocationId::generate();
assert_ne!(a, b);Trait Implementations
Sourceimpl AsRef<str> for InvocationId
impl AsRef<str> for InvocationId
Sourceimpl Borrow<str> for InvocationId
impl Borrow<str> for InvocationId
Sourceimpl Clone for InvocationId
impl Clone for InvocationId
Sourcefn clone(&self) -> InvocationId
fn clone(&self) -> InvocationId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvocationId
impl Debug for InvocationId
Sourceimpl<'de> Deserialize<'de> for InvocationId
impl<'de> Deserialize<'de> for InvocationId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<InvocationId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InvocationId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for InvocationId
impl Display for InvocationId
Sourceimpl FromStr for InvocationId
impl FromStr for InvocationId
Sourcetype Err = IdentityError
type Err = IdentityError
The associated error which can be returned from parsing.
Sourcefn from_str(s: &str) -> Result<InvocationId, <InvocationId as FromStr>::Err>
fn from_str(s: &str) -> Result<InvocationId, <InvocationId as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for InvocationId
impl Hash for InvocationId
Sourceimpl Ord for InvocationId
impl Ord for InvocationId
Sourcefn cmp(&self, other: &InvocationId) -> Ordering
fn cmp(&self, other: &InvocationId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InvocationId
impl PartialEq for InvocationId
Sourceimpl PartialOrd for InvocationId
impl PartialOrd for InvocationId
Sourceimpl Serialize for InvocationId
impl Serialize for InvocationId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<&str> for InvocationId
impl TryFrom<&str> for InvocationId
Sourcetype Error = IdentityError
type Error = IdentityError
The type returned in the event of a conversion error.
Sourcefn try_from(
s: &str,
) -> Result<InvocationId, <InvocationId as TryFrom<&str>>::Error>
fn try_from( s: &str, ) -> Result<InvocationId, <InvocationId as TryFrom<&str>>::Error>
Performs the conversion.
Sourceimpl TryFrom<String> for InvocationId
impl TryFrom<String> for InvocationId
Sourcetype Error = IdentityError
type Error = IdentityError
The type returned in the event of a conversion error.
Sourcefn try_from(
s: String,
) -> Result<InvocationId, <InvocationId as TryFrom<String>>::Error>
fn try_from( s: String, ) -> Result<InvocationId, <InvocationId as TryFrom<String>>::Error>
Performs the conversion.
impl Eq for InvocationId
impl StructuralPartialEq for InvocationId