pub struct GeminiModel { /* private fields */ }Available on crate features
models and gemini only.Implementations
Sourceimpl GeminiModel
impl GeminiModel
pub fn new( api_key: impl Into<String>, model: impl Into<String>, ) -> Result<GeminiModel, AdkError>
pub fn with_retry_config(self, retry_config: RetryConfig) -> GeminiModel
pub fn set_retry_config(&mut self, retry_config: RetryConfig)
pub fn retry_config(&self) -> &RetryConfig
Sourcepub async fn create_cached_content(
&self,
system_instruction: &str,
tools: &HashMap<String, Value>,
ttl_seconds: u32,
) -> Result<String, AdkError>
pub async fn create_cached_content( &self, system_instruction: &str, tools: &HashMap<String, Value>, ttl_seconds: u32, ) -> Result<String, AdkError>
Create a cached content resource with the given system instruction, tools, and TTL.
Returns the cache name (e.g., “cachedContents/abc123”) on success.
The cache is created using the model configured on this GeminiModel instance.