PromptCacheRetention

Enum PromptCacheRetention 

pub enum PromptCacheRetention {
    InMemory,
    TwentyFourHours,
}
Available on crate features models and openai only.
Prompt cache retention duration.

Controls how long prompt prefixes are cached for repeated requests. Caching reduces costs for requests that share the same prompt prefix.

Variants



InMemory

In-memory cache (shortest retention, lowest cost).



TwentyFourHours

24-hour cache retention.