pub enum ReasoningSummary {
Auto,
Concise,
Detailed,
}Available on crate features
models and openai only.Expand description
Reasoning summary mode for the Responses API.
Controls whether and how the model generates a summary of its internal reasoning process. Only applicable to o-series reasoning models.
Variants
Auto
Let the model decide whether to include a summary.
Concise
Include a brief summary of the reasoning.
Detailed
Include a thorough summary of the reasoning.