pub struct OpenRouterSseDecoder { /* private fields */ }Available on crate features
models and openrouter only.Expand description
Stateful SSE decoder that accepts arbitrarily chunked text input.
Implementations
Sourceimpl OpenRouterSseDecoder
impl OpenRouterSseDecoder
Sourcepub fn new() -> OpenRouterSseDecoder
pub fn new() -> OpenRouterSseDecoder
Create a new decoder with an empty internal buffer.
Sourcepub fn push(&mut self, chunk: &str) -> Vec<OpenRouterSseFrame>
pub fn push(&mut self, chunk: &str) -> Vec<OpenRouterSseFrame>
Push a UTF-8 text chunk into the decoder and return any completed SSE frames.
Sourcepub fn finish(self) -> Vec<OpenRouterSseFrame>
pub fn finish(self) -> Vec<OpenRouterSseFrame>
Drain any remaining complete frame buffered in the decoder.