pub struct OllamaModel { /* private fields */ }Available on crate feature
models only.Expand description
Ollama client for local LLM inference.
Implementations
Sourceimpl OllamaModel
impl OllamaModel
Sourcepub fn new(config: OllamaConfig) -> Result<OllamaModel, AdkError>
Available on crate feature ollama only.
pub fn new(config: OllamaConfig) -> Result<OllamaModel, AdkError>
ollama only.Create a new Ollama client with the given configuration.
Sourcepub fn from_model(model: impl Into<String>) -> Result<OllamaModel, AdkError>
Available on crate feature ollama only.
pub fn from_model(model: impl Into<String>) -> Result<OllamaModel, AdkError>
ollama only.Create a client with default settings for a given model.