Available on crate feature
payments only.Expand description
Agentic commerce and payment orchestration.
Provides protocol-neutral payment primitives and adapters for:
- ACP stable
2026-01-30 - ACP experimental surfaces behind
acp-experimental - AP2
v0.1-alphaas of2026-03-22
Available with feature: payments
Modules
- auth
- Payment authorization, actor binding, and audit integration points.
- domain
- Protocol-neutral commerce domain types.
- guardrail
- Payment-specific guardrails and redaction policies.
- journal
- Durable transaction journal, evidence storage, and safe memory indexing.
- kernel
- Canonical commerce kernel contracts.
- protocol
- Protocol adapter entry points.
- server
- Server and router integration for payment protocols.
- tools
- Agent-facing payment tool builders backed by the canonical commerce kernel.
Constants
- ACP_
DELEGATE_ AUTH_ BASELINE - ACP experimental delegated-authentication baseline version.
- ACP_
EXPERIMENTAL_ CHANNEL - ACP experimental compatibility channel supported behind
acp-experimental. - ACP_
STABLE_ BASELINE - ACP stable protocol baseline supported by this crate.
- AP2_
ALPHA_ BASELINE - AP2 protocol baseline supported by this crate.
- AP2_
ALPHA_ BASELINE_ DATE - Date of the AP2 alpha research baseline tracked by this crate.