pub struct OrderSnapshot {
pub order_id: Option<String>,
pub receipt_id: Option<String>,
pub state: OrderState,
pub receipt_state: ReceiptState,
pub extensions: ProtocolExtensions,
}Available on crate feature
payments only.Expand description
Canonical order and receipt summary attached to a transaction.
Fields
order_id: Option<String>receipt_id: Option<String>state: OrderStatereceipt_state: ReceiptStateextensions: ProtocolExtensionsImplementations
Sourceimpl OrderSnapshot
impl OrderSnapshot
Sourcepub fn transition_order_state(
&mut self,
next: OrderState,
) -> Result<(), PaymentsKernelError>
pub fn transition_order_state( &mut self, next: OrderState, ) -> Result<(), PaymentsKernelError>
Applies one canonical order-state transition.
Errors
Returns an error when the requested transition would skip or rewind the canonical order lifecycle.
Sourcepub fn transition_receipt_state(
&mut self,
next: ReceiptState,
) -> Result<(), PaymentsKernelError>
pub fn transition_receipt_state( &mut self, next: ReceiptState, ) -> Result<(), PaymentsKernelError>
Applies one canonical receipt-state transition.
Errors
Returns an error when the requested transition would skip or rewind the canonical receipt lifecycle.