pub struct ProtocolEnvelopeDigest {
pub evidence_ref: EvidenceReference,
pub created_at: DateTime<Utc>,
}Available on crate feature
payments only.Expand description
Safe digest metadata for one raw protocol artifact stored outside transcript and memory surfaces.
Fields
evidence_ref: EvidenceReferencecreated_at: DateTime<Utc>Implementations
Sourceimpl ProtocolEnvelopeDigest
impl ProtocolEnvelopeDigest
Sourcepub fn new(
evidence_ref: EvidenceReference,
created_at: DateTime<Utc>,
) -> ProtocolEnvelopeDigest
pub fn new( evidence_ref: EvidenceReference, created_at: DateTime<Utc>, ) -> ProtocolEnvelopeDigest
Creates a digest wrapper for one stored evidence reference.