pub struct TransactionLocator {
pub identity: AdkIdentity,
pub transaction_id: TransactionId,
}Available on crate feature
payments only.Expand description
Locates one journal entry by session identity plus canonical transaction ID.
Fields
identity: AdkIdentitytransaction_id: TransactionIdTrait Implementations
Sourceimpl Clone for TransactionLocator
impl Clone for TransactionLocator
Sourcefn clone(&self) -> TransactionLocator
fn clone(&self) -> TransactionLocator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionLocator
impl Debug for TransactionLocator
Sourceimpl<'de> Deserialize<'de> for TransactionLocator
impl<'de> Deserialize<'de> for TransactionLocator
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TransactionLocator, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TransactionLocator, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransactionLocator
impl PartialEq for TransactionLocator
Sourcefn eq(&self, other: &TransactionLocator) -> bool
fn eq(&self, other: &TransactionLocator) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TransactionLocator
impl Serialize for TransactionLocator
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for TransactionLocator
impl StructuralPartialEq for TransactionLocator