Module service

Module service 

Available on crate feature payments only.

Traits

DelegatedPaymentService
Backend-facing delegated-payment tokenization operations.
EvidenceStore
Raw evidence storage used to preserve immutable protocol artifacts.
InterventionService
Backend-facing intervention lifecycle operations.
MerchantCheckoutService
Backend-facing checkout operations shared by ACP and AP2 adapters.
PaymentExecutionService
Backend-facing payment execution operations shared by ACP and AP2 adapters.
TransactionStore
Durable structured transaction storage keyed by canonical transaction ID.