pub struct Plugin { /* private fields */ }Available on crate feature
plugin only.Expand description
A Plugin bundles related callbacks for extending agent behavior.
Plugins are registered with a PluginManager which coordinates callback execution across all registered plugins.
Example
ⓘ
use adk_plugin::{Plugin, PluginConfig};
// Create a caching plugin
let cache_plugin = Plugin::new(PluginConfig {
name: "cache".to_string(),
before_model: Some(Box::new(|ctx, request| {
Box::pin(async move {
// Check cache for this request
if let Some(cached) = check_cache(&request).await {
return Ok(BeforeModelResult::Skip(cached));
}
Ok(BeforeModelResult::Continue(request))
})
})),
after_model: Some(Box::new(|ctx, response| {
Box::pin(async move {
// Store response in cache
store_in_cache(&response).await;
Ok(None)
})
})),
..Default::default()
});Implementations
Sourceimpl Plugin
impl Plugin
Sourcepub fn new(config: PluginConfig) -> Plugin
pub fn new(config: PluginConfig) -> Plugin
Create a new plugin from configuration.
Sourcepub fn on_user_message(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>, Content) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
pub fn on_user_message( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>, Content) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
Get the on_user_message callback if set.
Sourcepub fn on_event(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>, Event) -> Pin<Box<dyn Future<Output = Result<Option<Event>, AdkError>> + Send>> + Sync + Send>>
pub fn on_event( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>, Event) -> Pin<Box<dyn Future<Output = Result<Option<Event>, AdkError>> + Send>> + Sync + Send>>
Get the on_event callback if set.
Sourcepub fn before_run(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
pub fn before_run( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
Get the before_run callback if set.
Sourcepub fn after_run(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>) -> Pin<Box<dyn Future<Output = ()> + Send>> + Sync + Send>>
pub fn after_run( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>) -> Pin<Box<dyn Future<Output = ()> + Send>> + Sync + Send>>
Get the after_run callback if set.
Sourcepub fn before_agent(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
pub fn before_agent( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
Get the before_agent callback if set.
Sourcepub fn after_agent(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
pub fn after_agent( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
Get the after_agent callback if set.
Sourcepub fn before_model(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmRequest) -> Pin<Box<dyn Future<Output = Result<BeforeModelResult, AdkError>> + Send>> + Sync + Send>>
pub fn before_model( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmRequest) -> Pin<Box<dyn Future<Output = Result<BeforeModelResult, AdkError>> + Send>> + Sync + Send>>
Get the before_model callback if set.
Sourcepub fn after_model(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmResponse) -> Pin<Box<dyn Future<Output = Result<Option<LlmResponse>, AdkError>> + Send>> + Sync + Send>>
pub fn after_model( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmResponse) -> Pin<Box<dyn Future<Output = Result<Option<LlmResponse>, AdkError>> + Send>> + Sync + Send>>
Get the after_model callback if set.
Sourcepub fn on_model_error(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmRequest, String) -> Pin<Box<dyn Future<Output = Result<Option<LlmResponse>, AdkError>> + Send>> + Sync + Send>>
pub fn on_model_error( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmRequest, String) -> Pin<Box<dyn Future<Output = Result<Option<LlmResponse>, AdkError>> + Send>> + Sync + Send>>
Get the on_model_error callback if set.
Sourcepub fn before_tool(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
pub fn before_tool( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
Get the before_tool callback if set.
Sourcepub fn after_tool(
&self,
) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
pub fn after_tool( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Sync + Send>>
Get the after_tool callback if set.