pub struct Arc<T, A = Global>{ /* private fields */ }Expand description
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
The type Arc<T> provides shared ownership of a value of type T,
allocated in the heap. Invoking clone on Arc produces
a new Arc instance, which points to the same allocation on the heap as the
source Arc, while increasing a reference count. When the last Arc
pointer to a given allocation is destroyed, the value stored in that allocation (often
referred to as “inner value”) is also dropped.
Shared references in Rust disallow mutation by default, and Arc is no
exception: you cannot generally obtain a mutable reference to something
inside an Arc. If you do need to mutate through an Arc, you have several options:
-
Use interior mutability with synchronization primitives like
Mutex,RwLock, or one of theAtomictypes. -
Use clone-on-write semantics with
Arc::make_mutwhich provides efficient mutation without requiring interior mutability. This approach clones the data only when needed (when there are multiple references) and can be more efficient when mutations are infrequent. -
Use
Arc::get_mutwhen you know yourArcis not shared (has a reference count of 1), which provides direct mutable access to the inner value without any cloning.
use std::sync::Arc;
let mut data = Arc::new(vec![1, 2, 3]);
// This will clone the vector only if there are other references to it
Arc::make_mut(&mut data).push(4);
assert_eq!(*data, vec![1, 2, 3, 4]);Note: This type is only available on platforms that support atomic
loads and stores of pointers, which includes all platforms that support
the std crate but not all those which only support alloc.
This may be detected at compile time using #[cfg(target_has_atomic = "ptr")].
Thread Safety
Unlike Rc<T>, Arc<T> uses atomic operations for its reference
counting. This means that it is thread-safe. The disadvantage is that
atomic operations are more expensive than ordinary memory accesses. If you
are not sharing reference-counted allocations between threads, consider using
Rc<T> for lower overhead. Rc<T> is a safe default, because the
compiler will catch any attempt to send an Rc<T> between threads.
However, a library might choose Arc<T> in order to give library consumers
more flexibility.
Arc<T> will implement Send and Sync as long as the T implements
Send and Sync. Why can’t you put a non-thread-safe type T in an
Arc<T> to make it thread-safe? This may be a bit counter-intuitive at
first: after all, isn’t the point of Arc<T> thread safety? The key is
this: Arc<T> makes it thread safe to have multiple ownership of the same
data, but it doesn’t add thread safety to its data. Consider
Arc<RefCell<T>>. RefCell<T> isn’t Sync, and if Arc<T> was always
Send, Arc<RefCell<T>> would be as well. But then we’d have a problem:
RefCell<T> is not thread safe; it keeps track of the borrowing count using
non-atomic operations.
In the end, this means that you may need to pair Arc<T> with some sort of
std::sync type, usually Mutex<T>.
Breaking cycles with Weak
The downgrade method can be used to create a non-owning
Weak pointer. A Weak pointer can be upgraded
to an Arc, but this will return None if the value stored in the allocation has
already been dropped. In other words, Weak pointers do not keep the value
inside the allocation alive; however, they do keep the allocation
(the backing store for the value) alive.
A cycle between Arc pointers will never be deallocated. For this reason,
Weak is used to break cycles. For example, a tree could have
strong Arc pointers from parent nodes to children, and Weak
pointers from children back to their parents.
Cloning references
Creating a new reference from an existing reference-counted pointer is done using the
Clone trait implemented for Arc<T> and Weak<T>.
use std::sync::Arc;
let foo = Arc::new(vec![1.0, 2.0, 3.0]);
// The two syntaxes below are equivalent.
let a = foo.clone();
let b = Arc::clone(&foo);
// a, b, and foo are all Arcs that point to the same memory locationDeref behavior
Arc<T> automatically dereferences to T (via the Deref trait),
so you can call T’s methods on a value of type Arc<T>. To avoid name
clashes with T’s methods, the methods of Arc<T> itself are associated
functions, called using fully qualified syntax:
use std::sync::Arc;
let my_arc = Arc::new(());
let my_weak = Arc::downgrade(&my_arc);Arc<T>’s implementations of traits like Clone may also be called using
fully qualified syntax. Some people prefer to use fully qualified syntax,
while others prefer using method-call syntax.
use std::sync::Arc;
let arc = Arc::new(());
// Method-call syntax
let arc2 = arc.clone();
// Fully qualified syntax
let arc3 = Arc::clone(&arc);Weak<T> does not auto-dereference to T, because the inner value may have
already been dropped.
Examples
Sharing some immutable data between threads:
use std::sync::Arc;
use std::thread;
let five = Arc::new(5);
for _ in 0..10 {
let five = Arc::clone(&five);
thread::spawn(move || {
println!("{five:?}");
});
}Sharing a mutable AtomicUsize:
use std::sync::Arc;
use std::sync::atomic::{AtomicUsize, Ordering};
use std::thread;
let val = Arc::new(AtomicUsize::new(5));
for _ in 0..10 {
let val = Arc::clone(&val);
thread::spawn(move || {
let v = val.fetch_add(1, Ordering::Relaxed);
println!("{v:?}");
});
}See the rc documentation for more examples of reference
counting in general.
Implementations
Sourceimpl<T> Arc<T>
impl<T> Arc<T>
1.0.0 · Sourcepub fn new(data: T) -> Arc<T> ⓘ
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new(data: T) -> Arc<T> ⓘ
mcp and crate feature tools and non-no_global_oom_handling only.1.60.0 · Sourcepub fn new_cyclic<F>(data_fn: F) -> Arc<T> ⓘ
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_cyclic<F>(data_fn: F) -> Arc<T> ⓘ
mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc<T> while giving you a Weak<T> to the allocation,
to allow you to construct a T which holds a weak pointer to itself.
Generally, a structure circularly referencing itself, either directly or
indirectly, should not hold a strong reference to itself to prevent a memory leak.
Using this function, you get access to the weak pointer during the
initialization of T, before the Arc<T> is created, such that you can
clone and store it inside the T.
new_cyclic first allocates the managed allocation for the Arc<T>,
then calls your closure, giving it a Weak<T> to this allocation,
and only afterwards completes the construction of the Arc<T> by placing
the T returned from your closure into the allocation.
Since the new Arc<T> is not fully-constructed until Arc<T>::new_cyclic
returns, calling upgrade on the weak reference inside your closure will
fail and result in a None value.
Panics
If data_fn panics, the panic is propagated to the caller, and the
temporary Weak<T> is dropped normally.
Example
use std::sync::{Arc, Weak};
struct Gadget {
me: Weak<Gadget>,
}
impl Gadget {
/// Constructs a reference counted Gadget.
fn new() -> Arc<Self> {
// `me` is a `Weak<Gadget>` pointing at the new allocation of the
// `Arc` we're constructing.
Arc::new_cyclic(|me| {
// Create the actual struct here.
Gadget { me: me.clone() }
})
}
/// Returns a reference counted pointer to Self.
fn me(&self) -> Arc<Self> {
self.me.upgrade().unwrap()
}
}1.82.0 · Sourcepub fn new_uninit() -> Arc<MaybeUninit<T>> ⓘ
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_uninit() -> Arc<MaybeUninit<T>> ⓘ
mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc with uninitialized contents.
Examples
use std::sync::Arc;
let mut five = Arc::<u32>::new_uninit();
// Deferred initialization:
Arc::get_mut(&mut five).unwrap().write(5);
let five = unsafe { five.assume_init() };
assert_eq!(*five, 5)1.92.0 · Sourcepub fn new_zeroed() -> Arc<MaybeUninit<T>> ⓘ
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_zeroed() -> Arc<MaybeUninit<T>> ⓘ
mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc with uninitialized contents, with the memory
being filled with 0 bytes.
See MaybeUninit::zeroed for examples of correct and incorrect usage
of this method.
Examples
use std::sync::Arc;
let zero = Arc::<u32>::new_zeroed();
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0)1.33.0 · Sourcepub fn pin(data: T) -> Pin<Arc<T>>
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn pin(data: T) -> Pin<Arc<T>>
mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Pin<Arc<T>>. If T does not implement Unpin, then
data will be pinned in memory and unable to be moved.
Sourcepub fn try_pin(data: T) -> Result<Pin<Arc<T>>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_pin(data: T) -> Result<Pin<Arc<T>>, AllocError>
allocator_api)mcp and tools only.Constructs a new Pin<Arc<T>>, return an error if allocation fails.
Sourcepub fn try_new(data: T) -> Result<Arc<T>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_new(data: T) -> Result<Arc<T>, AllocError>
allocator_api)mcp and tools only.Constructs a new Arc<T>, returning an error if allocation fails.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
let five = Arc::try_new(5)?;Sourcepub fn try_new_uninit() -> Result<Arc<MaybeUninit<T>>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_new_uninit() -> Result<Arc<MaybeUninit<T>>, AllocError>
allocator_api)mcp and tools only.Constructs a new Arc with uninitialized contents, returning an error
if allocation fails.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
let mut five = Arc::<u32>::try_new_uninit()?;
// Deferred initialization:
Arc::get_mut(&mut five).unwrap().write(5);
let five = unsafe { five.assume_init() };
assert_eq!(*five, 5);Sourcepub fn try_new_zeroed() -> Result<Arc<MaybeUninit<T>>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_new_zeroed() -> Result<Arc<MaybeUninit<T>>, AllocError>
allocator_api)mcp and tools only.Constructs a new Arc with uninitialized contents, with the memory
being filled with 0 bytes, returning an error if allocation fails.
See MaybeUninit::zeroed for examples of correct and incorrect usage
of this method.
Examples
#![feature( allocator_api)]
use std::sync::Arc;
let zero = Arc::<u32>::try_new_zeroed()?;
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0);Sourcepub fn map<U>(this: Arc<T>, f: impl FnOnce(&T) -> U) -> Arc<U> ⓘ
🔬This is a nightly-only experimental API. (smart_pointer_try_map)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn map<U>(this: Arc<T>, f: impl FnOnce(&T) -> U) -> Arc<U> ⓘ
smart_pointer_try_map)mcp and crate feature tools and non-no_global_oom_handling only.Maps the value in an Arc, reusing the allocation if possible.
f is called on a reference to the value in the Arc, and the result is returned, also in
an Arc.
Note: this is an associated function, which means that you have
to call it as Arc::map(a, f) instead of r.map(a). This
is so that there is no conflict with a method on the inner type.
Examples
#![feature(smart_pointer_try_map)]
use std::sync::Arc;
let r = Arc::new(7);
let new = Arc::map(r, |i| i + 7);
assert_eq!(*new, 14);Sourcepub fn try_map<R>(
this: Arc<T>,
f: impl FnOnce(&T) -> R,
) -> <<R as Try>::Residual as Residual<Arc<<R as Try>::Output>>>::TryType
🔬This is a nightly-only experimental API. (smart_pointer_try_map)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn try_map<R>( this: Arc<T>, f: impl FnOnce(&T) -> R, ) -> <<R as Try>::Residual as Residual<Arc<<R as Try>::Output>>>::TryType
smart_pointer_try_map)mcp and crate feature tools and non-no_global_oom_handling only.Attempts to map the value in an Arc, reusing the allocation if possible.
f is called on a reference to the value in the Arc, and if the operation succeeds, the
result is returned, also in an Arc.
Note: this is an associated function, which means that you have
to call it as Arc::try_map(a, f) instead of a.try_map(f). This
is so that there is no conflict with a method on the inner type.
Examples
#![feature(smart_pointer_try_map)]
use std::sync::Arc;
let b = Arc::new(7);
let new = Arc::try_map(b, |&i| u32::try_from(i)).unwrap();
assert_eq!(*new, 7);Sourceimpl<T, A> Arc<T, A>where
A: Allocator,
impl<T, A> Arc<T, A>where
A: Allocator,
Sourcepub fn new_in(data: T, alloc: A) -> Arc<T, A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_in(data: T, alloc: A) -> Arc<T, A> ⓘ
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc<T> in the provided allocator.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let five = Arc::new_in(5, System);Sourcepub fn new_uninit_in(alloc: A) -> Arc<MaybeUninit<T>, A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_uninit_in(alloc: A) -> Arc<MaybeUninit<T>, A> ⓘ
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc with uninitialized contents in the provided allocator.
Examples
#![feature(get_mut_unchecked)]
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let mut five = Arc::<u32, _>::new_uninit_in(System);
let five = unsafe {
// Deferred initialization:
Arc::get_mut_unchecked(&mut five).as_mut_ptr().write(5);
five.assume_init()
};
assert_eq!(*five, 5)Sourcepub fn new_zeroed_in(alloc: A) -> Arc<MaybeUninit<T>, A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_zeroed_in(alloc: A) -> Arc<MaybeUninit<T>, A> ⓘ
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc with uninitialized contents, with the memory
being filled with 0 bytes, in the provided allocator.
See MaybeUninit::zeroed for examples of correct and incorrect usage
of this method.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let zero = Arc::<u32, _>::new_zeroed_in(System);
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0)Sourcepub fn new_cyclic_in<F>(data_fn: F, alloc: A) -> Arc<T, A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_cyclic_in<F>(data_fn: F, alloc: A) -> Arc<T, A> ⓘ
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc<T, A> in the given allocator while giving you a Weak<T, A> to the allocation,
to allow you to construct a T which holds a weak pointer to itself.
Generally, a structure circularly referencing itself, either directly or
indirectly, should not hold a strong reference to itself to prevent a memory leak.
Using this function, you get access to the weak pointer during the
initialization of T, before the Arc<T, A> is created, such that you can
clone and store it inside the T.
new_cyclic_in first allocates the managed allocation for the Arc<T, A>,
then calls your closure, giving it a Weak<T, A> to this allocation,
and only afterwards completes the construction of the Arc<T, A> by placing
the T returned from your closure into the allocation.
Since the new Arc<T, A> is not fully-constructed until Arc<T, A>::new_cyclic_in
returns, calling upgrade on the weak reference inside your closure will
fail and result in a None value.
Panics
If data_fn panics, the panic is propagated to the caller, and the
temporary Weak<T> is dropped normally.
Example
See new_cyclic
Sourcepub fn pin_in(data: T, alloc: A) -> Pin<Arc<T, A>>where
A: 'static,
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn pin_in(data: T, alloc: A) -> Pin<Arc<T, A>>where
A: 'static,
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Pin<Arc<T, A>> in the provided allocator. If T does not implement Unpin,
then data will be pinned in memory and unable to be moved.
Sourcepub fn try_pin_in(data: T, alloc: A) -> Result<Pin<Arc<T, A>>, AllocError>where
A: 'static,
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_pin_in(data: T, alloc: A) -> Result<Pin<Arc<T, A>>, AllocError>where
A: 'static,
allocator_api)mcp and tools only.Constructs a new Pin<Arc<T, A>> in the provided allocator, return an error if allocation
fails.
Sourcepub fn try_new_in(data: T, alloc: A) -> Result<Arc<T, A>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_new_in(data: T, alloc: A) -> Result<Arc<T, A>, AllocError>
allocator_api)mcp and tools only.Constructs a new Arc<T, A> in the provided allocator, returning an error if allocation fails.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let five = Arc::try_new_in(5, System)?;Sourcepub fn try_new_uninit_in(alloc: A) -> Result<Arc<MaybeUninit<T>, A>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_new_uninit_in(alloc: A) -> Result<Arc<MaybeUninit<T>, A>, AllocError>
allocator_api)mcp and tools only.Constructs a new Arc with uninitialized contents, in the provided allocator, returning an
error if allocation fails.
Examples
#![feature(allocator_api)]
#![feature(get_mut_unchecked)]
use std::sync::Arc;
use std::alloc::System;
let mut five = Arc::<u32, _>::try_new_uninit_in(System)?;
let five = unsafe {
// Deferred initialization:
Arc::get_mut_unchecked(&mut five).as_mut_ptr().write(5);
five.assume_init()
};
assert_eq!(*five, 5);Sourcepub fn try_new_zeroed_in(alloc: A) -> Result<Arc<MaybeUninit<T>, A>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn try_new_zeroed_in(alloc: A) -> Result<Arc<MaybeUninit<T>, A>, AllocError>
allocator_api)mcp and tools only.Constructs a new Arc with uninitialized contents, with the memory
being filled with 0 bytes, in the provided allocator, returning an error if allocation
fails.
See MaybeUninit::zeroed for examples of correct and incorrect usage
of this method.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let zero = Arc::<u32, _>::try_new_zeroed_in(System)?;
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0);1.4.0 · Sourcepub fn try_unwrap(this: Arc<T, A>) -> Result<T, Arc<T, A>>
Available on crate features mcp and tools only.
pub fn try_unwrap(this: Arc<T, A>) -> Result<T, Arc<T, A>>
mcp and tools only.Returns the inner value, if the Arc has exactly one strong reference.
Otherwise, an Err is returned with the same Arc that was
passed in.
This will succeed even if there are outstanding weak references.
It is strongly recommended to use Arc::into_inner instead if you don’t
keep the Arc in the Err case.
Immediately dropping the Err-value, as the expression
Arc::try_unwrap(this).ok() does, can cause the strong count to
drop to zero and the inner value of the Arc to be dropped.
For instance, if two threads execute such an expression in parallel,
there is a race condition without the possibility of unsafety:
The threads could first both check whether they own the last instance
in Arc::try_unwrap, determine that they both do not, and then both
discard and drop their instance in the call to ok.
In this scenario, the value inside the Arc is safely destroyed
by exactly one of the threads, but neither thread will ever be able
to use the value.
Examples
use std::sync::Arc;
let x = Arc::new(3);
assert_eq!(Arc::try_unwrap(x), Ok(3));
let x = Arc::new(4);
let _y = Arc::clone(&x);
assert_eq!(*Arc::try_unwrap(x).unwrap_err(), 4);1.70.0 · Sourcepub fn into_inner(this: Arc<T, A>) -> Option<T>
Available on crate features mcp and tools only.
pub fn into_inner(this: Arc<T, A>) -> Option<T>
mcp and tools only.Returns the inner value, if the Arc has exactly one strong reference.
Otherwise, None is returned and the Arc is dropped.
This will succeed even if there are outstanding weak references.
If Arc::into_inner is called on every clone of this Arc,
it is guaranteed that exactly one of the calls returns the inner value.
This means in particular that the inner value is not dropped.
Arc::try_unwrap is conceptually similar to Arc::into_inner, but it
is meant for different use-cases. If used as a direct replacement
for Arc::into_inner anyway, such as with the expression
Arc::try_unwrap(this).ok(), then it does
not give the same guarantee as described in the previous paragraph.
For more information, see the examples below and read the documentation
of Arc::try_unwrap.
Examples
Minimal example demonstrating the guarantee that Arc::into_inner gives.
use std::sync::Arc;
let x = Arc::new(3);
let y = Arc::clone(&x);
// Two threads calling `Arc::into_inner` on both clones of an `Arc`:
let x_thread = std::thread::spawn(|| Arc::into_inner(x));
let y_thread = std::thread::spawn(|| Arc::into_inner(y));
let x_inner_value = x_thread.join().unwrap();
let y_inner_value = y_thread.join().unwrap();
// One of the threads is guaranteed to receive the inner value:
assert!(matches!(
(x_inner_value, y_inner_value),
(None, Some(3)) | (Some(3), None)
));
// The result could also be `(None, None)` if the threads called
// `Arc::try_unwrap(x).ok()` and `Arc::try_unwrap(y).ok()` instead.A more practical example demonstrating the need for Arc::into_inner:
use std::sync::Arc;
// Definition of a simple singly linked list using `Arc`:
#[derive(Clone)]
struct LinkedList<T>(Option<Arc<Node<T>>>);
struct Node<T>(T, Option<Arc<Node<T>>>);
// Dropping a long `LinkedList<T>` relying on the destructor of `Arc`
// can cause a stack overflow. To prevent this, we can provide a
// manual `Drop` implementation that does the destruction in a loop:
impl<T> Drop for LinkedList<T> {
fn drop(&mut self) {
let mut link = self.0.take();
while let Some(arc_node) = link.take() {
if let Some(Node(_value, next)) = Arc::into_inner(arc_node) {
link = next;
}
}
}
}
// Implementation of `new` and `push` omitted
impl<T> LinkedList<T> {
/* ... */
}
// The following code could have still caused a stack overflow
// despite the manual `Drop` impl if that `Drop` impl had used
// `Arc::try_unwrap(arc).ok()` instead of `Arc::into_inner(arc)`.
// Create a long list and clone it
let mut x = LinkedList::new();
let size = 100000;
for i in 0..size {
x.push(i); // Adds i to the front of x
}
let y = x.clone();
// Drop the clones in parallel
let x_thread = std::thread::spawn(|| drop(x));
let y_thread = std::thread::spawn(|| drop(y));
x_thread.join().unwrap();
y_thread.join().unwrap();Sourceimpl<T> Arc<[T]>
impl<T> Arc<[T]>
1.82.0 · Sourcepub fn new_uninit_slice(len: usize) -> Arc<[MaybeUninit<T>]> ⓘ
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_uninit_slice(len: usize) -> Arc<[MaybeUninit<T>]> ⓘ
mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new atomically reference-counted slice with uninitialized contents.
Examples
use std::sync::Arc;
let mut values = Arc::<[u32]>::new_uninit_slice(3);
// Deferred initialization:
let data = Arc::get_mut(&mut values).unwrap();
data[0].write(1);
data[1].write(2);
data[2].write(3);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [1, 2, 3])1.92.0 · Sourcepub fn new_zeroed_slice(len: usize) -> Arc<[MaybeUninit<T>]> ⓘ
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_zeroed_slice(len: usize) -> Arc<[MaybeUninit<T>]> ⓘ
mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new atomically reference-counted slice with uninitialized contents, with the memory being
filled with 0 bytes.
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
use std::sync::Arc;
let values = Arc::<[u32]>::new_zeroed_slice(3);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [0, 0, 0])Sourceimpl<T, A> Arc<[T], A>where
A: Allocator,
impl<T, A> Arc<[T], A>where
A: Allocator,
Sourcepub fn new_uninit_slice_in(len: usize, alloc: A) -> Arc<[MaybeUninit<T>], A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_uninit_slice_in(len: usize, alloc: A) -> Arc<[MaybeUninit<T>], A> ⓘ
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new atomically reference-counted slice with uninitialized contents in the provided allocator.
Examples
#![feature(get_mut_unchecked)]
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let mut values = Arc::<[u32], _>::new_uninit_slice_in(3, System);
let values = unsafe {
// Deferred initialization:
Arc::get_mut_unchecked(&mut values)[0].as_mut_ptr().write(1);
Arc::get_mut_unchecked(&mut values)[1].as_mut_ptr().write(2);
Arc::get_mut_unchecked(&mut values)[2].as_mut_ptr().write(3);
values.assume_init()
};
assert_eq!(*values, [1, 2, 3])Sourcepub fn new_zeroed_slice_in(len: usize, alloc: A) -> Arc<[MaybeUninit<T>], A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn new_zeroed_slice_in(len: usize, alloc: A) -> Arc<[MaybeUninit<T>], A> ⓘ
allocator_api)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new atomically reference-counted slice with uninitialized contents, with the memory being
filled with 0 bytes, in the provided allocator.
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let values = Arc::<[u32], _>::new_zeroed_slice_in(3, System);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [0, 0, 0])Sourcepub fn into_array<const N: usize>(self) -> Result<Arc<[T; N], A>, Arc<[T], A>>
🔬This is a nightly-only experimental API. (alloc_slice_into_array)Available on crate features mcp and tools only.
pub fn into_array<const N: usize>(self) -> Result<Arc<[T; N], A>, Arc<[T], A>>
alloc_slice_into_array)mcp and tools only.Converts the reference-counted slice into a reference-counted array.
This operation does not reallocate; the underlying array of the slice is simply reinterpreted as an array type.
Errors
Returns the original Arc<[T]> in the Err variant if self.len() does not equal N.
Examples
#![feature(alloc_slice_into_array)]
use std::sync::Arc;
let arc_slice: Arc<[i32]> = Arc::new([1, 2, 3]);
let arc_array: Arc<[i32; 3]> = arc_slice.into_array().unwrap();Sourceimpl<T, A> Arc<MaybeUninit<T>, A>where
A: Allocator,
impl<T, A> Arc<MaybeUninit<T>, A>where
A: Allocator,
1.82.0 · Sourcepub unsafe fn assume_init(self) -> Arc<T, A> ⓘ
Available on crate features mcp and tools only.
pub unsafe fn assume_init(self) -> Arc<T, A> ⓘ
mcp and tools only.Converts to Arc<T>.
Safety
As with MaybeUninit::assume_init,
it is up to the caller to guarantee that the inner value
really is in an initialized state.
Calling this when the content is not yet fully initialized
causes immediate undefined behavior.
Examples
use std::sync::Arc;
let mut five = Arc::<u32>::new_uninit();
// Deferred initialization:
Arc::get_mut(&mut five).unwrap().write(5);
let five = unsafe { five.assume_init() };
assert_eq!(*five, 5)Sourceimpl<T> Arc<T>where
T: CloneToUninit + ?Sized,
impl<T> Arc<T>where
T: CloneToUninit + ?Sized,
Sourcepub fn clone_from_ref(value: &T) -> Arc<T> ⓘ
🔬This is a nightly-only experimental API. (clone_from_ref)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn clone_from_ref(value: &T) -> Arc<T> ⓘ
clone_from_ref)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc<T> with a clone of value.
Examples
#![feature(clone_from_ref)]
use std::sync::Arc;
let hello: Arc<str> = Arc::clone_from_ref("hello");Sourcepub fn try_clone_from_ref(value: &T) -> Result<Arc<T>, AllocError>
🔬This is a nightly-only experimental API. (clone_from_ref)Available on crate features mcp and tools only.
pub fn try_clone_from_ref(value: &T) -> Result<Arc<T>, AllocError>
clone_from_ref)mcp and tools only.Constructs a new Arc<T> with a clone of value, returning an error if allocation fails
Examples
#![feature(clone_from_ref)]
#![feature(allocator_api)]
use std::sync::Arc;
let hello: Arc<str> = Arc::try_clone_from_ref("hello")?;Sourceimpl<T, A> Arc<T, A>
impl<T, A> Arc<T, A>
Sourcepub fn clone_from_ref_in(value: &T, alloc: A) -> Arc<T, A> ⓘ
🔬This is a nightly-only experimental API. (clone_from_ref)Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn clone_from_ref_in(value: &T, alloc: A) -> Arc<T, A> ⓘ
clone_from_ref)mcp and crate feature tools and non-no_global_oom_handling only.Constructs a new Arc<T> with a clone of value in the provided allocator.
Examples
#![feature(clone_from_ref)]
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let hello: Arc<str, System> = Arc::clone_from_ref_in("hello", System);Sourcepub fn try_clone_from_ref_in(
value: &T,
alloc: A,
) -> Result<Arc<T, A>, AllocError>
🔬This is a nightly-only experimental API. (clone_from_ref)Available on crate features mcp and tools only.
pub fn try_clone_from_ref_in( value: &T, alloc: A, ) -> Result<Arc<T, A>, AllocError>
clone_from_ref)mcp and tools only.Constructs a new Arc<T> with a clone of value in the provided allocator, returning an error if allocation fails
Examples
#![feature(clone_from_ref)]
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let hello: Arc<str, System> = Arc::try_clone_from_ref_in("hello", System)?;Sourceimpl<T, A> Arc<[MaybeUninit<T>], A>where
A: Allocator,
impl<T, A> Arc<[MaybeUninit<T>], A>where
A: Allocator,
1.82.0 · Sourcepub unsafe fn assume_init(self) -> Arc<[T], A> ⓘ
Available on crate features mcp and tools only.
pub unsafe fn assume_init(self) -> Arc<[T], A> ⓘ
mcp and tools only.Converts to Arc<[T]>.
Safety
As with MaybeUninit::assume_init,
it is up to the caller to guarantee that the inner value
really is in an initialized state.
Calling this when the content is not yet fully initialized
causes immediate undefined behavior.
Examples
use std::sync::Arc;
let mut values = Arc::<[u32]>::new_uninit_slice(3);
// Deferred initialization:
let data = Arc::get_mut(&mut values).unwrap();
data[0].write(1);
data[1].write(2);
data[2].write(3);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [1, 2, 3])Sourceimpl<T> Arc<T>where
T: ?Sized,
impl<T> Arc<T>where
T: ?Sized,
1.17.0 · Sourcepub unsafe fn from_raw(ptr: *const T) -> Arc<T> ⓘ
Available on crate features mcp and tools only.
pub unsafe fn from_raw(ptr: *const T) -> Arc<T> ⓘ
mcp and tools only.Constructs an Arc<T> from a raw pointer.
The raw pointer must have been previously returned by a call to
Arc<U>::into_raw or Arc<U>::into_raw_with_allocator.
Safety
- Creating a
Arc<T>from a pointer other than one returned fromArc<U>::into_raworArc<U>::into_raw_with_allocatoris undefined behavior. - If
Uis sized, it must have the same size and alignment asT. This is trivially true ifUisT. - If
Uis unsized, its data pointer must have the same size and alignment asT. This is trivially true ifArc<U>was constructed throughArc<T>and then converted toArc<U>through an unsized coercion. - Note that if
UorU’s data pointer is notTbut has the same size and alignment, this is basically like transmuting references of different types. Seemem::transmutefor more information on what restrictions apply in this case. - The raw pointer must point to a block of memory allocated by the global allocator.
- The user of
from_rawhas to make sure a specific value ofTis only dropped once.
This function is unsafe because improper use may lead to memory unsafety,
even if the returned Arc<T> is never accessed.
Examples
use std::sync::Arc;
let x = Arc::new("hello".to_owned());
let x_ptr = Arc::into_raw(x);
unsafe {
// Convert back to an `Arc` to prevent leak.
let x = Arc::from_raw(x_ptr);
assert_eq!(&*x, "hello");
// Further calls to `Arc::from_raw(x_ptr)` would be memory-unsafe.
}
// The memory was freed when `x` went out of scope above, so `x_ptr` is now dangling!Convert a slice back into its original array:
use std::sync::Arc;
let x: Arc<[u32]> = Arc::new([1, 2, 3]);
let x_ptr: *const [u32] = Arc::into_raw(x);
unsafe {
let x: Arc<[u32; 3]> = Arc::from_raw(x_ptr.cast::<[u32; 3]>());
assert_eq!(&*x, &[1, 2, 3]);
}1.17.0 · Sourcepub fn into_raw(this: Arc<T>) -> *const T
Available on crate features mcp and tools only.
pub fn into_raw(this: Arc<T>) -> *const T
mcp and tools only.Consumes the Arc, returning the wrapped pointer.
To avoid a memory leak the pointer must be converted back to an Arc using
Arc::from_raw.
Examples
use std::sync::Arc;
let x = Arc::new("hello".to_owned());
let x_ptr = Arc::into_raw(x);
assert_eq!(unsafe { &*x_ptr }, "hello");1.51.0 · Sourcepub unsafe fn increment_strong_count(ptr: *const T)
Available on crate features mcp and tools only.
pub unsafe fn increment_strong_count(ptr: *const T)
mcp and tools only.Increments the strong reference count on the Arc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Arc::into_raw and must satisfy the
same layout requirements specified in Arc::from_raw_in.
The associated Arc instance must be valid (i.e. the strong count must be at
least 1) for the duration of this method, and ptr must point to a block of memory
allocated by the global allocator.
Examples
use std::sync::Arc;
let five = Arc::new(5);
unsafe {
let ptr = Arc::into_raw(five);
Arc::increment_strong_count(ptr);
// This assertion is deterministic because we haven't shared
// the `Arc` between threads.
let five = Arc::from_raw(ptr);
assert_eq!(2, Arc::strong_count(&five));
}1.51.0 · Sourcepub unsafe fn decrement_strong_count(ptr: *const T)
Available on crate features mcp and tools only.
pub unsafe fn decrement_strong_count(ptr: *const T)
mcp and tools only.Decrements the strong reference count on the Arc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Arc::into_raw and must satisfy the
same layout requirements specified in Arc::from_raw_in.
The associated Arc instance must be valid (i.e. the strong count must be at
least 1) when invoking this method, and ptr must point to a block of memory
allocated by the global allocator. This method can be used to release the final
Arc and backing storage, but should not be called after the final Arc has been
released.
Examples
use std::sync::Arc;
let five = Arc::new(5);
unsafe {
let ptr = Arc::into_raw(five);
Arc::increment_strong_count(ptr);
// Those assertions are deterministic because we haven't shared
// the `Arc` between threads.
let five = Arc::from_raw(ptr);
assert_eq!(2, Arc::strong_count(&five));
Arc::decrement_strong_count(ptr);
assert_eq!(1, Arc::strong_count(&five));
}Sourceimpl<T, A> Arc<T, A>
impl<T, A> Arc<T, A>
Sourcepub fn allocator(this: &Arc<T, A>) -> &A
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn allocator(this: &Arc<T, A>) -> &A
allocator_api)mcp and tools only.Returns a reference to the underlying allocator.
Note: this is an associated function, which means that you have
to call it as Arc::allocator(&a) instead of a.allocator(). This
is so that there is no conflict with a method on the inner type.
Sourcepub fn into_raw_with_allocator(this: Arc<T, A>) -> (*const T, A)
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub fn into_raw_with_allocator(this: Arc<T, A>) -> (*const T, A)
allocator_api)mcp and tools only.Consumes the Arc, returning the wrapped pointer and allocator.
To avoid a memory leak the pointer must be converted back to an Arc using
Arc::from_raw_in.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let x = Arc::new_in("hello".to_owned(), System);
let (ptr, alloc) = Arc::into_raw_with_allocator(x);
assert_eq!(unsafe { &*ptr }, "hello");
let x = unsafe { Arc::from_raw_in(ptr, alloc) };
assert_eq!(&*x, "hello");1.45.0 · Sourcepub fn as_ptr(this: &Arc<T, A>) -> *const T
Available on crate features mcp and tools only.
pub fn as_ptr(this: &Arc<T, A>) -> *const T
mcp and tools only.Provides a raw pointer to the data.
The counts are not affected in any way and the Arc is not consumed. The pointer is valid for
as long as there are strong counts in the Arc.
Examples
use std::sync::Arc;
let x = Arc::new("hello".to_owned());
let y = Arc::clone(&x);
let x_ptr = Arc::as_ptr(&x);
assert_eq!(x_ptr, Arc::as_ptr(&y));
assert_eq!(unsafe { &*x_ptr }, "hello");Sourcepub unsafe fn from_raw_in(ptr: *const T, alloc: A) -> Arc<T, A> ⓘ
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub unsafe fn from_raw_in(ptr: *const T, alloc: A) -> Arc<T, A> ⓘ
allocator_api)mcp and tools only.Constructs an Arc<T, A> from a raw pointer.
The raw pointer must have been previously returned by a call to Arc<U, A>::into_raw or Arc<U, A>::into_raw_with_allocator.
Safety
- Creating a
Arc<T, A>from a pointer other than one returned fromArc<U, A>::into_raworArc<U, A>::into_raw_with_allocatoris undefined behavior. - If
Uis sized, it must have the same size and alignment asT. This is trivially true ifUisT. - If
Uis unsized, its data pointer must have the same size and alignment asT. This is trivially true ifArc<U, A>was constructed throughArc<T, A>and then converted toArc<U, A>through an unsized coercion. - Note that if
UorU’s data pointer is notTbut has the same size and alignment, this is basically like transmuting references of different types. Seemem::transmutefor more information on what restrictions apply in this case. - The raw pointer must point to a block of memory allocated by
alloc - The user of
from_rawhas to make sure a specific value ofTis only dropped once.
This function is unsafe because improper use may lead to memory unsafety,
even if the returned Arc<T> is never accessed.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let x = Arc::new_in("hello".to_owned(), System);
let (x_ptr, alloc) = Arc::into_raw_with_allocator(x);
unsafe {
// Convert back to an `Arc` to prevent leak.
let x = Arc::from_raw_in(x_ptr, System);
assert_eq!(&*x, "hello");
// Further calls to `Arc::from_raw(x_ptr)` would be memory-unsafe.
}
// The memory was freed when `x` went out of scope above, so `x_ptr` is now dangling!Convert a slice back into its original array:
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let x: Arc<[u32], _> = Arc::new_in([1, 2, 3], System);
let x_ptr: *const [u32] = Arc::into_raw_with_allocator(x).0;
unsafe {
let x: Arc<[u32; 3], _> = Arc::from_raw_in(x_ptr.cast::<[u32; 3]>(), System);
assert_eq!(&*x, &[1, 2, 3]);
}1.4.0 · Sourcepub fn downgrade(this: &Arc<T, A>) -> Weak<T, A>where
A: Clone,
Available on crate features mcp and tools only.
pub fn downgrade(this: &Arc<T, A>) -> Weak<T, A>where
A: Clone,
mcp and tools only.1.15.0 · Sourcepub fn weak_count(this: &Arc<T, A>) -> usize
Available on crate features mcp and tools only.
pub fn weak_count(this: &Arc<T, A>) -> usize
mcp and tools only.Gets the number of Weak pointers to this allocation.
Safety
This method by itself is safe, but using it correctly requires extra care. Another thread can change the weak count at any time, including potentially between calling this method and acting on the result.
Examples
use std::sync::Arc;
let five = Arc::new(5);
let _weak_five = Arc::downgrade(&five);
// This assertion is deterministic because we haven't shared
// the `Arc` or `Weak` between threads.
assert_eq!(1, Arc::weak_count(&five));1.15.0 · Sourcepub fn strong_count(this: &Arc<T, A>) -> usize
Available on crate features mcp and tools only.
pub fn strong_count(this: &Arc<T, A>) -> usize
mcp and tools only.Gets the number of strong (Arc) pointers to this allocation.
Safety
This method by itself is safe, but using it correctly requires extra care. Another thread can change the strong count at any time, including potentially between calling this method and acting on the result.
Examples
use std::sync::Arc;
let five = Arc::new(5);
let _also_five = Arc::clone(&five);
// This assertion is deterministic because we haven't shared
// the `Arc` between threads.
assert_eq!(2, Arc::strong_count(&five));Sourcepub unsafe fn increment_strong_count_in(ptr: *const T, alloc: A)where
A: Clone,
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub unsafe fn increment_strong_count_in(ptr: *const T, alloc: A)where
A: Clone,
allocator_api)mcp and tools only.Increments the strong reference count on the Arc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Arc::into_raw and must satisfy the
same layout requirements specified in Arc::from_raw_in.
The associated Arc instance must be valid (i.e. the strong count must be at
least 1) for the duration of this method, and ptr must point to a block of memory
allocated by alloc.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let five = Arc::new_in(5, System);
unsafe {
let (ptr, _alloc) = Arc::into_raw_with_allocator(five);
Arc::increment_strong_count_in(ptr, System);
// This assertion is deterministic because we haven't shared
// the `Arc` between threads.
let five = Arc::from_raw_in(ptr, System);
assert_eq!(2, Arc::strong_count(&five));
}Sourcepub unsafe fn decrement_strong_count_in(ptr: *const T, alloc: A)
🔬This is a nightly-only experimental API. (allocator_api)Available on crate features mcp and tools only.
pub unsafe fn decrement_strong_count_in(ptr: *const T, alloc: A)
allocator_api)mcp and tools only.Decrements the strong reference count on the Arc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Arc::into_raw and must satisfy the
same layout requirements specified in Arc::from_raw_in.
The associated Arc instance must be valid (i.e. the strong count must be at
least 1) when invoking this method, and ptr must point to a block of memory
allocated by alloc. This method can be used to release the final
Arc and backing storage, but should not be called after the final Arc has been
released.
Examples
#![feature(allocator_api)]
use std::sync::Arc;
use std::alloc::System;
let five = Arc::new_in(5, System);
unsafe {
let (ptr, _alloc) = Arc::into_raw_with_allocator(five);
Arc::increment_strong_count_in(ptr, System);
// Those assertions are deterministic because we haven't shared
// the `Arc` between threads.
let five = Arc::from_raw_in(ptr, System);
assert_eq!(2, Arc::strong_count(&five));
Arc::decrement_strong_count_in(ptr, System);
assert_eq!(1, Arc::strong_count(&five));
}1.17.0 · Sourcepub fn ptr_eq(this: &Arc<T, A>, other: &Arc<T, A>) -> bool
Available on crate features mcp and tools only.
pub fn ptr_eq(this: &Arc<T, A>, other: &Arc<T, A>) -> bool
mcp and tools only.Returns true if the two Arcs point to the same allocation in a vein similar to
ptr::eq. This function ignores the metadata of dyn Trait pointers.
Examples
use std::sync::Arc;
let five = Arc::new(5);
let same_five = Arc::clone(&five);
let other_five = Arc::new(5);
assert!(Arc::ptr_eq(&five, &same_five));
assert!(!Arc::ptr_eq(&five, &other_five));Sourceimpl<T, A> Arc<T, A>
impl<T, A> Arc<T, A>
1.4.0 · Sourcepub fn make_mut(this: &mut Arc<T, A>) -> &mut T
Available on crate feature mcp and crate feature tools and non-no_global_oom_handling only.
pub fn make_mut(this: &mut Arc<T, A>) -> &mut T
mcp and crate feature tools and non-no_global_oom_handling only.Makes a mutable reference into the given Arc.
If there are other Arc pointers to the same allocation, then make_mut will
clone the inner value to a new allocation to ensure unique ownership. This is also
referred to as clone-on-write.
However, if there are no other Arc pointers to this allocation, but some Weak
pointers, then the Weak pointers will be dissociated and the inner value will not
be cloned.
See also get_mut, which will fail rather than cloning the inner value
or dissociating Weak pointers.
Examples
use std::sync::Arc;
let mut data = Arc::new(5);
*Arc::make_mut(&mut data) += 1; // Won't clone anything
let mut other_data = Arc::clone(&data); // Won't clone inner data
*Arc::make_mut(&mut data) += 1; // Clones inner data
*Arc::make_mut(&mut data) += 1; // Won't clone anything
*Arc::make_mut(&mut other_data) *= 2; // Won't clone anything
// Now `data` and `other_data` point to different allocations.
assert_eq!(*data, 8);
assert_eq!(*other_data, 12);Weak pointers will be dissociated:
use std::sync::Arc;
let mut data = Arc::new(75);
let weak = Arc::downgrade(&data);
assert!(75 == *data);
assert!(75 == *weak.upgrade().unwrap());
*Arc::make_mut(&mut data) += 1;
assert!(76 == *data);
assert!(weak.upgrade().is_none());Sourceimpl<T, A> Arc<T, A>
impl<T, A> Arc<T, A>
1.76.0 · Sourcepub fn unwrap_or_clone(this: Arc<T, A>) -> T
Available on crate features mcp and tools only.
pub fn unwrap_or_clone(this: Arc<T, A>) -> T
mcp and tools only.If we have the only reference to T then unwrap it. Otherwise, clone T and return the
clone.
Assuming arc_t is of type Arc<T>, this function is functionally equivalent to
(*arc_t).clone(), but will avoid cloning the inner value where possible.
Examples
let inner = String::from("test");
let ptr = inner.as_ptr();
let arc = Arc::new(inner);
let inner = Arc::unwrap_or_clone(arc);
// The inner value was not cloned
assert!(ptr::eq(ptr, inner.as_ptr()));
let arc = Arc::new(inner);
let arc2 = arc.clone();
let inner = Arc::unwrap_or_clone(arc);
// Because there were 2 references, we had to clone the inner value.
assert!(!ptr::eq(ptr, inner.as_ptr()));
// `arc2` is the last reference, so when we unwrap it we get back
// the original `String`.
let inner = Arc::unwrap_or_clone(arc2);
assert!(ptr::eq(ptr, inner.as_ptr()));Sourceimpl<T, A> Arc<T, A>
impl<T, A> Arc<T, A>
1.4.0 · Sourcepub fn get_mut(this: &mut Arc<T, A>) -> Option<&mut T>
Available on crate features mcp and tools only.
pub fn get_mut(this: &mut Arc<T, A>) -> Option<&mut T>
mcp and tools only.Returns a mutable reference into the given Arc, if there are
no other Arc or Weak pointers to the same allocation.
Returns None otherwise, because it is not safe to
mutate a shared value.
See also make_mut, which will clone
the inner value when there are other Arc pointers.
Examples
use std::sync::Arc;
let mut x = Arc::new(3);
*Arc::get_mut(&mut x).unwrap() = 4;
assert_eq!(*x, 4);
let _y = Arc::clone(&x);
assert!(Arc::get_mut(&mut x).is_none());Sourcepub unsafe fn get_mut_unchecked(this: &mut Arc<T, A>) -> &mut T
🔬This is a nightly-only experimental API. (get_mut_unchecked)Available on crate features mcp and tools only.
pub unsafe fn get_mut_unchecked(this: &mut Arc<T, A>) -> &mut T
get_mut_unchecked)mcp and tools only.Returns a mutable reference into the given Arc,
without any check.
See also get_mut, which is safe and does appropriate checks.
Safety
If any other Arc or Weak pointers to the same allocation exist, then
they must not be dereferenced or have active borrows for the duration
of the returned borrow, and their inner type must be exactly the same as the
inner type of this Arc (including lifetimes). This is trivially the case if no
such pointers exist, for example immediately after Arc::new.
Examples
#![feature(get_mut_unchecked)]
use std::sync::Arc;
let mut x = Arc::new(String::new());
unsafe {
Arc::get_mut_unchecked(&mut x).push_str("foo")
}
assert_eq!(*x, "foo");Other Arc pointers to the same allocation must be to the same type.
#![feature(get_mut_unchecked)]
use std::sync::Arc;
let x: Arc<str> = Arc::from("Hello, world!");
let mut y: Arc<[u8]> = x.clone().into();
unsafe {
// this is Undefined Behavior, because x's inner type is str, not [u8]
Arc::get_mut_unchecked(&mut y).fill(0xff); // 0xff is invalid in UTF-8
}
println!("{}", &*x); // Invalid UTF-8 in a strOther Arc pointers to the same allocation must be to the exact same type, including lifetimes.
#![feature(get_mut_unchecked)]
use std::sync::Arc;
let x: Arc<&str> = Arc::new("Hello, world!");
{
let s = String::from("Oh, no!");
let mut y: Arc<&str> = x.clone();
unsafe {
// this is Undefined Behavior, because x's inner type
// is &'long str, not &'short str
*Arc::get_mut_unchecked(&mut y) = &s;
}
}
println!("{}", &*x); // Use-after-freeSourcepub fn is_unique(this: &Arc<T, A>) -> bool
🔬This is a nightly-only experimental API. (arc_is_unique)Available on crate features mcp and tools only.
pub fn is_unique(this: &Arc<T, A>) -> bool
arc_is_unique)mcp and tools only.Determine whether this is the unique reference to the underlying data.
Returns true if there are no other Arc or Weak pointers to the same allocation;
returns false otherwise.
If this function returns true, then is guaranteed to be safe to call get_mut_unchecked
on this Arc, so long as no clones occur in between.
Examples
#![feature(arc_is_unique)]
use std::sync::Arc;
let x = Arc::new(3);
assert!(Arc::is_unique(&x));
let y = Arc::clone(&x);
assert!(!Arc::is_unique(&x));
drop(y);
// Weak references also count, because they could be upgraded at any time.
let z = Arc::downgrade(&x);
assert!(!Arc::is_unique(&x));Pointer invalidation
This function will always return the same value as Arc::get_mut(arc).is_some(). However,
unlike that operation it does not produce any mutable references to the underlying data,
meaning no pointers to the data inside the Arc are invalidated by the call. Thus, the
following code is valid, even though it would be UB if it used Arc::get_mut:
#![feature(arc_is_unique)]
use std::sync::Arc;
let arc = Arc::new(5);
let pointer: *const i32 = &*arc;
assert!(Arc::is_unique(&arc));
assert_eq!(unsafe { *pointer }, 5);Atomic orderings
Concurrent drops to other Arc pointers to the same allocation will synchronize with this
call - that is, this call performs an Acquire operation on the underlying strong and weak
ref counts. This ensures that calling get_mut_unchecked is safe.
Note that this operation requires locking the weak ref count, so concurrent calls to
downgrade may spin-loop for a short period of time.
Sourceimpl<A> Arc<dyn Any + Sync + Send, A>where
A: Allocator,
impl<A> Arc<dyn Any + Sync + Send, A>where
A: Allocator,
1.29.0 · Sourcepub fn downcast<T>(self) -> Result<Arc<T, A>, Arc<dyn Any + Sync + Send, A>>
Available on crate features mcp and tools only.
pub fn downcast<T>(self) -> Result<Arc<T, A>, Arc<dyn Any + Sync + Send, A>>
mcp and tools only.Attempts to downcast the Arc<dyn Any + Send + Sync> to a concrete type.
Examples
use std::any::Any;
use std::sync::Arc;
fn print_if_string(value: Arc<dyn Any + Send + Sync>) {
if let Ok(string) = value.downcast::<String>() {
println!("String ({}): {}", string.len(), string);
}
}
let my_string = "Hello World".to_string();
print_if_string(Arc::new(my_string));
print_if_string(Arc::new(0i8));Sourcepub unsafe fn downcast_unchecked<T>(self) -> Arc<T, A> ⓘ
🔬This is a nightly-only experimental API. (downcast_unchecked)Available on crate features mcp and tools only.
pub unsafe fn downcast_unchecked<T>(self) -> Arc<T, A> ⓘ
downcast_unchecked)mcp and tools only.Downcasts the Arc<dyn Any + Send + Sync> to a concrete type.
For a safe alternative see downcast.
Examples
#![feature(downcast_unchecked)]
use std::any::Any;
use std::sync::Arc;
let x: Arc<dyn Any + Send + Sync> = Arc::new(1_usize);
unsafe {
assert_eq!(*x.downcast_unchecked::<usize>(), 1);
}Safety
The contained value must be of type T. Calling this method
with the incorrect type is undefined behavior.