Module embedding

Module embedding 

Available on crate feature rag only.
Embedding provider trait for generating vector embeddings from text.

Traits

EmbeddingProvider
A provider that generates vector embeddings from text input.