pub enum ContextMutationOutcome {
Applied,
RequiresResumption(Box<RealtimeConfig>),
}Available on crate feature
realtime only.Expand description
The outcome of an attempt to mutate the session context mid-flight.
Variants
Applied
Provider successfully updated the active session via sideband.
RequiresResumption(Box<RealtimeConfig>)
Provider requires the transport to be rebound with a new configuration.