pub struct RunnerConfigBuilder<A, G, S> { /* private fields */ }Available on crate feature
runner only.Expand description
A typestate builder for constructing a Runner.
The three type parameters track whether the required fields have been
provided. build() is only available when all three are Has*.
Implementations
Sourceimpl RunnerConfigBuilder<NoAppName, NoAgent, NoSessionService>
impl RunnerConfigBuilder<NoAppName, NoAgent, NoSessionService>
Sourcepub fn new() -> RunnerConfigBuilder<NoAppName, NoAgent, NoSessionService>
pub fn new() -> RunnerConfigBuilder<NoAppName, NoAgent, NoSessionService>
Create a new builder with all fields unset and defaults applied.
Sourceimpl<A, G, S> RunnerConfigBuilder<A, G, S>
impl<A, G, S> RunnerConfigBuilder<A, G, S>
Sourcepub fn app_name(
self,
name: impl Into<String>,
) -> RunnerConfigBuilder<HasAppName, G, S>
pub fn app_name( self, name: impl Into<String>, ) -> RunnerConfigBuilder<HasAppName, G, S>
Set the application name (required).
Sourcepub fn agent(self, agent: Arc<dyn Agent>) -> RunnerConfigBuilder<A, HasAgent, S>
pub fn agent(self, agent: Arc<dyn Agent>) -> RunnerConfigBuilder<A, HasAgent, S>
Set the root agent (required).
Sourcepub fn session_service(
self,
service: Arc<dyn SessionService>,
) -> RunnerConfigBuilder<A, G, HasSessionService>
pub fn session_service( self, service: Arc<dyn SessionService>, ) -> RunnerConfigBuilder<A, G, HasSessionService>
Set the session service (required).
Sourceimpl<A, G, S> RunnerConfigBuilder<A, G, S>
impl<A, G, S> RunnerConfigBuilder<A, G, S>
Sourcepub fn artifact_service(
self,
service: Arc<dyn ArtifactService>,
) -> RunnerConfigBuilder<A, G, S>
pub fn artifact_service( self, service: Arc<dyn ArtifactService>, ) -> RunnerConfigBuilder<A, G, S>
Set the artifact service (optional).
Sourcepub fn memory_service(
self,
service: Arc<dyn Memory>,
) -> RunnerConfigBuilder<A, G, S>
pub fn memory_service( self, service: Arc<dyn Memory>, ) -> RunnerConfigBuilder<A, G, S>
Set the memory service (optional).
Sourcepub fn plugin_manager(
self,
manager: Arc<PluginManager>,
) -> RunnerConfigBuilder<A, G, S>
pub fn plugin_manager( self, manager: Arc<PluginManager>, ) -> RunnerConfigBuilder<A, G, S>
Set the plugin manager (optional).
Sourcepub fn run_config(self, config: RunConfig) -> RunnerConfigBuilder<A, G, S>
pub fn run_config(self, config: RunConfig) -> RunnerConfigBuilder<A, G, S>
Set the run configuration (optional).
Sourcepub fn compaction_config(
self,
config: EventsCompactionConfig,
) -> RunnerConfigBuilder<A, G, S>
pub fn compaction_config( self, config: EventsCompactionConfig, ) -> RunnerConfigBuilder<A, G, S>
Set the events compaction configuration (optional).
Sourcepub fn context_cache_config(
self,
config: ContextCacheConfig,
) -> RunnerConfigBuilder<A, G, S>
pub fn context_cache_config( self, config: ContextCacheConfig, ) -> RunnerConfigBuilder<A, G, S>
Set the context cache configuration (optional).
Sourcepub fn cache_capable(
self,
model: Arc<dyn CacheCapable>,
) -> RunnerConfigBuilder<A, G, S>
pub fn cache_capable( self, model: Arc<dyn CacheCapable>, ) -> RunnerConfigBuilder<A, G, S>
Set the cache-capable model reference (optional).
Sourcepub fn request_context(
self,
ctx: RequestContext,
) -> RunnerConfigBuilder<A, G, S>
pub fn request_context( self, ctx: RequestContext, ) -> RunnerConfigBuilder<A, G, S>
Set the request context from auth middleware (optional).
Sourcepub fn cancellation_token(
self,
token: CancellationToken,
) -> RunnerConfigBuilder<A, G, S>
pub fn cancellation_token( self, token: CancellationToken, ) -> RunnerConfigBuilder<A, G, S>
Set a cooperative cancellation token (optional).