pub struct WrappedCommand {
pub program: OsString,
pub args: Vec<OsString>,
}Available on crate feature
sandbox only.Expand description
The result of wrapping a command with sandbox enforcement.
Contains the new program to execute and the full argument list (sandbox wrapper args + original program + original args).
Fields
program: OsStringThe program to execute (e.g., “sandbox-exec”, “bwrap”, or the original program for Windows).
args: Vec<OsString>The full argument list including wrapper args, separator, and original args.