pub struct A2aServerApp { /* private fields */ }Available on crate feature
server only.Expand description
A configured A2A server application ready to serve.
Created via A2aServerBuilder::build. Provides access to the
underlying Axum router and a convenience serve
method for binding and listening.
Implementations
Sourceimpl A2aServerApp
impl A2aServerApp
Sourcepub fn into_router(self) -> Router
Available on crate feature a2a-v1 only.
pub fn into_router(self) -> Router
a2a-v1 only.Consume the app and return the underlying Axum router.
Use this when you need to compose the A2A routes with other Axum routers or middleware.
Sourcepub fn bind_addr(&self) -> &str
Available on crate feature a2a-v1 only.
pub fn bind_addr(&self) -> &str
a2a-v1 only.Get the configured bind address.