Module event

Module event 

Available on crate feature sessions only.
Event types and the Events trait for accessing session event history.

Structs

Event
Event represents a single interaction in a conversation. This struct embeds LlmResponse to match ADK-Go’s design pattern.
EventActions
Actions to apply as side effects of an event.

Traits

Events
Trait for accessing events in a session.