Available on crate feature
sessions only.Expand description
Session service trait and request/response types.
Structs
- Append
Event Request - Request to append an event to a session using typed
AdkIdentityaddressing. - Create
Request - Request to create a new session.
- Delete
Request - Request to delete a session.
- GetRequest
- Request to retrieve an existing session.
- List
Request - Request to list sessions for a given app and user.
Traits
- Session
Service - Trait for session persistence backends.