pub struct GoogleSearchTool;tools only.Expand description
GoogleSearch is a built-in tool that is automatically invoked by Gemini models to retrieve search results from Google Search. The tool operates internally within the model and does not require or perform local code execution.
Implementations
Sourceimpl GoogleSearchTool
impl GoogleSearchTool
Sourcepub fn new() -> GoogleSearchTool
pub fn new() -> GoogleSearchTool
Create a new GoogleSearchTool.