pub struct Json<T>(pub T);Available on crate features
mcp and server and tools only.Expand description
Json wrapper for structured output
When used with tools, this wrapper indicates that the value should be
serialized as structured JSON content with an associated schema.
The framework will place the JSON in the structured_content field
of the tool result rather than the regular content field.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> IntoCallToolResult for Json<T>where
T: Serialize + JsonSchema + 'static,
impl<T> IntoCallToolResult for Json<T>where
T: Serialize + JsonSchema + 'static,
fn into_call_tool_result(self) -> Result<CallToolResponse, ErrorData>
Sourceimpl<T> JsonSchema for Json<T>where
T: JsonSchema,
impl<T> JsonSchema for Json<T>where
T: JsonSchema,
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl<T> Freeze for Json<T>where
T: Freeze,
impl<T> RefUnwindSafe for Json<T>where
T: RefUnwindSafe,
impl<T> Send for Json<T>where
T: Send,
impl<T> Sync for Json<T>where
T: Sync,
impl<T> Unpin for Json<T>where
T: Unpin,
impl<T> UnsafeUnpin for Json<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for Json<T>where
T: UnwindSafe,