#[non_exhaustive]pub enum PrimitiveSchemaDefinition {
Enum(EnumSchema),
String(StringSchema),
Number(NumberSchema),
Integer(IntegerSchema),
Boolean(BooleanSchema),
}Available on crate features
mcp and tools only.Expand description
Primitive schema definition for elicitation properties.
According to MCP 2025-06-18 specification, elicitation schemas must have properties of primitive types only (string, number, integer, boolean, enum).
Note: Put Enum as the first variant to avoid ambiguity during deserialization. This is due to the fact that EnumSchema can contain StringSchema internally and serde uses first match wins strategy when deserializing untagged enums.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Enum(EnumSchema)
Enum property (explicit enum schema)
String(StringSchema)
String property (with optional enum constraint)
Number(NumberSchema)
Number property (with optional enum constraint)
Integer(IntegerSchema)
Integer property (with optional enum constraint)
Boolean(BooleanSchema)
Boolean property