#[non_exhaustive]pub enum SamplingMessageContentBlock {
Text(TextContent),
Image(ImageContent),
Audio(AudioContent),
ToolUse(ToolUseContent),
ToolResult(ToolResultContent),
}Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
mcp and tools only.Expand description
Content types for sampling messages (SEP-1577).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Text(TextContent)
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Image(ImageContent)
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Audio(AudioContent)
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
ToolUse(ToolUseContent)
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Assistant only
ToolResult(ToolResultContent)
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
User only
Implementations
Sourceimpl SamplingMessageContentBlock
impl SamplingMessageContentBlock
Sourcepub fn as_text(&self) -> Option<&TextContent>
pub fn as_text(&self) -> Option<&TextContent>
Get the text content if this is a Text variant
Sourcepub fn as_tool_use(&self) -> Option<&ToolUseContent>
pub fn as_tool_use(&self) -> Option<&ToolUseContent>
Get the tool use content if this is a ToolUse variant
Sourcepub fn as_tool_result(&self) -> Option<&ToolResultContent>
pub fn as_tool_result(&self) -> Option<&ToolResultContent>
Get the tool result content if this is a ToolResult variant
Sourceimpl SamplingMessageContentBlock
impl SamplingMessageContentBlock
Sourcepub fn text(text: impl Into<String>) -> SamplingMessageContentBlock
pub fn text(text: impl Into<String>) -> SamplingMessageContentBlock
Create a text content
pub fn tool_use( id: impl Into<String>, name: impl Into<String>, input: Map<String, Value>, ) -> SamplingMessageContentBlock
pub fn tool_result( tool_use_id: impl Into<String>, content: Vec<ContentBlock>, ) -> SamplingMessageContentBlock