pub struct ClientCapabilitiesBuilder<S = ClientCapabilitiesBuilderState> {
pub experimental: Option<BTreeMap<String, Map<String, Value>>>,
pub extensions: Option<BTreeMap<String, Map<String, Value>>>,
pub roots: Option<RootsCapabilities>,
pub sampling: Option<SamplingCapability>,
pub elicitation: Option<ElicitationCapability>,
pub state: PhantomData<S>,
}mcp and tools only.Fields
experimental: Option<BTreeMap<String, Map<String, Value>>>extensions: Option<BTreeMap<String, Map<String, Value>>>roots: Option<RootsCapabilities>sampling: Option<SamplingCapability>elicitation: Option<ElicitationCapability>state: PhantomData<S>Implementations
Sourceimpl<S> ClientCapabilitiesBuilder<S>
impl<S> ClientCapabilitiesBuilder<S>
pub fn build(self) -> ClientCapabilities
Sourceimpl<const EXTENSIONS: bool, const ROOTS: bool, const SAMPLING: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<false, EXTENSIONS, ROOTS, SAMPLING, ELICITATION>>
impl<const EXTENSIONS: bool, const ROOTS: bool, const SAMPLING: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<false, EXTENSIONS, ROOTS, SAMPLING, ELICITATION>>
pub fn enable_experimental( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<true, EXTENSIONS, ROOTS, SAMPLING, ELICITATION>>
pub fn enable_experimental_with( self, experimental: BTreeMap<String, Map<String, Value>>, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<true, EXTENSIONS, ROOTS, SAMPLING, ELICITATION>>
Sourceimpl<const EXPERIMENTAL: bool, const ROOTS: bool, const SAMPLING: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, false, ROOTS, SAMPLING, ELICITATION>>
impl<const EXPERIMENTAL: bool, const ROOTS: bool, const SAMPLING: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, false, ROOTS, SAMPLING, ELICITATION>>
pub fn enable_extensions( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, true, ROOTS, SAMPLING, ELICITATION>>
pub fn enable_extensions_with( self, extensions: BTreeMap<String, Map<String, Value>>, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, true, ROOTS, SAMPLING, ELICITATION>>
Sourceimpl<const EXPERIMENTAL: bool, const EXTENSIONS: bool, const SAMPLING: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, false, SAMPLING, ELICITATION>>
impl<const EXPERIMENTAL: bool, const EXTENSIONS: bool, const SAMPLING: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, false, SAMPLING, ELICITATION>>
pub fn enable_roots( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, true, SAMPLING, ELICITATION>>
Roots is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
pub fn enable_roots_with( self, roots: RootsCapabilities, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, true, SAMPLING, ELICITATION>>
Roots is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Sourceimpl<const EXPERIMENTAL: bool, const EXTENSIONS: bool, const ROOTS: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, false, ELICITATION>>
impl<const EXPERIMENTAL: bool, const EXTENSIONS: bool, const ROOTS: bool, const ELICITATION: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, false, ELICITATION>>
pub fn enable_sampling( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, true, ELICITATION>>
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
pub fn enable_sampling_with( self, sampling: SamplingCapability, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, true, ELICITATION>>
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Sourceimpl<const EXPERIMENTAL: bool, const EXTENSIONS: bool, const ROOTS: bool, const SAMPLING: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, SAMPLING>>
impl<const EXPERIMENTAL: bool, const EXTENSIONS: bool, const ROOTS: bool, const SAMPLING: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, SAMPLING>>
pub fn enable_elicitation( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, SAMPLING, true>>
pub fn enable_elicitation_with( self, elicitation: ElicitationCapability, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<EXPERIMENTAL, EXTENSIONS, ROOTS, SAMPLING, true>>
Sourceimpl<S> ClientCapabilitiesBuilder<S>
impl<S> ClientCapabilitiesBuilder<S>
Sourcepub fn enable_tasks(self) -> ClientCapabilitiesBuilder<S>
Available on crate features macros or server only.
pub fn enable_tasks(self) -> ClientCapabilitiesBuilder<S>
macros or server only.Declare support for the io.modelcontextprotocol/tasks extension
(SEP-2663) in the extensions capability map.
Sourceimpl<const E: bool, const EXT: bool, const S: bool, const EL: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, true, S, EL>>
impl<const E: bool, const EXT: bool, const S: bool, const EL: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, true, S, EL>>
pub fn enable_roots_list_changed( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, true, S, EL>>
Roots is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
macros or server only.Sourceimpl<const E: bool, const EXT: bool, const R: bool, const EL: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, true, EL>>
impl<const E: bool, const EXT: bool, const R: bool, const EL: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, true, EL>>
Sourcepub fn enable_sampling_tools(
self,
) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, true, EL>>
👎Deprecated since 1.8.0: Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Available on crate features macros or server only.
pub fn enable_sampling_tools( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, true, EL>>
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
macros or server only.Enable tool calling in sampling requests
Sourcepub fn enable_sampling_context(
self,
) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, true, EL>>
👎Deprecated since 1.8.0: Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Available on crate features macros or server only.
pub fn enable_sampling_context( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, true, EL>>
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
macros or server only.Enable context inclusion in sampling (soft-deprecated)
Sourceimpl<const E: bool, const EXT: bool, const R: bool, const S: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, S, true>>
impl<const E: bool, const EXT: bool, const R: bool, const S: bool> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, S, true>>
Sourcepub fn enable_elicitation_schema_validation(
self,
) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, S, true>>
Available on crate feature elicitation and (crate features macros or server) only.
pub fn enable_elicitation_schema_validation( self, ) -> ClientCapabilitiesBuilder<ClientCapabilitiesBuilderState<E, EXT, R, S, true>>
elicitation and (crate features macros or server) only.Enable JSON Schema validation for elicitation responses in form mode. When enabled, the client will validate user input against the requested_schema before sending responses back to the server.