#[non_exhaustive]pub struct CreateMessageRequestParams {
pub meta: Option<RequestMetaObject>,
pub messages: Vec<SamplingMessage>,
pub model_preferences: Option<ModelPreferences>,
pub system_prompt: Option<String>,
pub include_context: Option<ContextInclusion>,
pub temperature: Option<f32>,
pub max_tokens: u32,
pub stop_sequences: Option<Vec<String>>,
pub metadata: Option<Value>,
pub tools: Option<Vec<Tool>>,
pub tool_choice: Option<ToolChoice>,
}Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
mcp and tools only.Expand description
Parameters for creating a message through LLM sampling.
This structure contains all the necessary information for a client to generate an LLM response, including conversation history, model preferences, and generation parameters.
This implements TaskAugmentedRequestParamsMeta as sampling requests can be
long-running and may benefit from task-based execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<RequestMetaObject>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Protocol-level metadata for this request (SEP-1319)
messages: Vec<SamplingMessage>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
The conversation history and current messages
model_preferences: Option<ModelPreferences>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Preferences for model selection and behavior
system_prompt: Option<String>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
System prompt to guide the modelโs behavior
include_context: Option<ContextInclusion>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
How much context to include from MCP servers
temperature: Option<f32>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Temperature for controlling randomness (0.0 to 1.0)
max_tokens: u32Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Maximum number of tokens to generate
stop_sequences: Option<Vec<String>>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Sequences that should stop generation
metadata: Option<Value>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Additional metadata for the request
tools: Option<Vec<Tool>>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Tools available for the model to call (SEP-1577)
tool_choice: Option<ToolChoice>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Tool selection behavior (SEP-1577)
Implementations
Sourceimpl CreateMessageRequestParams
impl CreateMessageRequestParams
Sourcepub fn new(
messages: Vec<SamplingMessage>,
max_tokens: u32,
) -> CreateMessageRequestParams
pub fn new( messages: Vec<SamplingMessage>, max_tokens: u32, ) -> CreateMessageRequestParams
Create a new CreateMessageRequestParams with required fields.
Sourcepub fn with_model_preferences(
self,
model_preferences: ModelPreferences,
) -> CreateMessageRequestParams
pub fn with_model_preferences( self, model_preferences: ModelPreferences, ) -> CreateMessageRequestParams
Set model preferences.
Sourcepub fn with_system_prompt(
self,
system_prompt: impl Into<String>,
) -> CreateMessageRequestParams
pub fn with_system_prompt( self, system_prompt: impl Into<String>, ) -> CreateMessageRequestParams
Set system prompt.
Sourcepub fn with_include_context(
self,
include_context: ContextInclusion,
) -> CreateMessageRequestParams
pub fn with_include_context( self, include_context: ContextInclusion, ) -> CreateMessageRequestParams
Set include context.
Sourcepub fn with_temperature(self, temperature: f32) -> CreateMessageRequestParams
pub fn with_temperature(self, temperature: f32) -> CreateMessageRequestParams
Set temperature.
Sourcepub fn with_stop_sequences(
self,
stop_sequences: Vec<String>,
) -> CreateMessageRequestParams
pub fn with_stop_sequences( self, stop_sequences: Vec<String>, ) -> CreateMessageRequestParams
Set stop sequences.
Sourcepub fn with_metadata(self, metadata: Value) -> CreateMessageRequestParams
pub fn with_metadata(self, metadata: Value) -> CreateMessageRequestParams
Set metadata.
Sourcepub fn with_tools(self, tools: Vec<Tool>) -> CreateMessageRequestParams
pub fn with_tools(self, tools: Vec<Tool>) -> CreateMessageRequestParams
Set tools.
Sourcepub fn with_tool_choice(
self,
tool_choice: ToolChoice,
) -> CreateMessageRequestParams
pub fn with_tool_choice( self, tool_choice: ToolChoice, ) -> CreateMessageRequestParams
Set tool choice.
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Validate the sampling request parameters per SEP-1577 spec requirements.
Checks:
- ToolUse content is only allowed in assistant messages
- ToolResult content is only allowed in user messages
- Messages with tool result content MUST NOT contain other content types
- Every assistant ToolUse must be balanced with a corresponding user ToolResult