#[non_exhaustive]pub struct CreateMessageResult {
pub model: String,
pub stop_reason: Option<String>,
pub message: SamplingMessage,
}Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
mcp and tools only.Expand description
Result of sampling/createMessage (SEP-1577). The result of a sampling/createMessage request containing the generated response.
This structure contains the generated message along with metadata about how the generation was performed and why it stopped.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.model: StringSampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
The identifier of the model that generated the response
stop_reason: Option<String>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
The reason why generation stopped (e.g., โendTurnโ, โmaxTokensโ)
message: SamplingMessageSampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
The generated message with role and content
Implementations
Sourceimpl CreateMessageResult
impl CreateMessageResult
pub const STOP_REASON_END_TURN: &'static str = "endTurn"
pub const STOP_REASON_END_SEQUENCE: &'static str = "stopSequence"
pub const STOP_REASON_END_MAX_TOKEN: &'static str = "maxTokens"
pub const STOP_REASON_TOOL_USE: &'static str = "toolUse"
Sourcepub fn new(message: SamplingMessage, model: String) -> CreateMessageResult
pub fn new(message: SamplingMessage, model: String) -> CreateMessageResult
Create a new CreateMessageResult with required fields.
Sourcepub fn with_stop_reason(
self,
stop_reason: impl Into<String>,
) -> CreateMessageResult
pub fn with_stop_reason( self, stop_reason: impl Into<String>, ) -> CreateMessageResult
Set the stop reason.
Sourcepub fn with_model(self, model: impl Into<String>) -> CreateMessageResult
pub fn with_model(self, model: impl Into<String>) -> CreateMessageResult
Set the model identifier.