InitializeRequestParams

Struct InitializeRequestParams 

#[non_exhaustive]
pub struct InitializeRequestParams { pub meta: Option<RequestMetaObject>, pub protocol_version: ProtocolVersion, pub capabilities: ClientCapabilities, pub client_info: Implementation, }
Available on crate features mcp and tools only.
Parameters sent by a client when initializing a connection to an MCP server.

This contains the client’s protocol version, capabilities, and implementation information, allowing the server to understand what the client supports.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
meta: Option<RequestMetaObject>

Protocol-level metadata for this request (SEP-1319)

protocol_version: ProtocolVersion

The MCP protocol version this client supports

capabilities: ClientCapabilities

The capabilities this client supports (sampling, roots, etc.)

client_info: Implementation

Information about the client implementation

Implementations

Source

impl InitializeRequestParams

pub fn new( capabilities: ClientCapabilities, client_info: Implementation, ) -> InitializeRequestParams

Create a new InitializeRequestParams.

pub fn with_protocol_version( self, protocol_version: ProtocolVersion, ) -> InitializeRequestParams