#[non_exhaustive]pub struct ModelHint {
pub name: Option<String>,
}๐Deprecated since 2.0.0:
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Available on crate features
mcp and tools only.Expand description
A hint suggesting a preferred model name or family.
Model hints are advisory suggestions that help clients choose appropriate models. They can be specific model names or general families like โclaudeโ or โgptโ.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>๐Deprecated since 2.0.0:
Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
The suggested model name or family identifier
Implementations