ModelPreferences

Struct ModelPreferences 

#[non_exhaustive]
pub struct ModelPreferences { pub hints: Option<Vec<ModelHint>>, pub cost_priority: Option<f32>, pub speed_priority: Option<f32>, pub intelligence_priority: Option<f32>, }
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Available on crate features mcp and tools only.
Preferences for model selection and behavior in sampling requests.

This allows servers to express their preferences for which model to use and how to balance different priorities when the client has multiple model options available.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
hints: Option<Vec<ModelHint>>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Specific model names or families to prefer (e.g., โ€œclaudeโ€, โ€œgptโ€)

cost_priority: Option<f32>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Priority for cost optimization (0.0 to 1.0, higher = prefer cheaper models)

speed_priority: Option<f32>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Priority for speed/latency (0.0 to 1.0, higher = prefer faster models)

intelligence_priority: Option<f32>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Priority for intelligence/capability (0.0 to 1.0, higher = prefer more capable models)

Implementations

Source

impl ModelPreferences

pub fn new() -> ModelPreferences

Create a new default ModelPreferences.

pub fn with_hints(self, hints: Vec<ModelHint>) -> ModelPreferences

Set hints for model selection.

pub fn with_cost_priority(self, cost_priority: f32) -> ModelPreferences

Set cost priority (0.0 to 1.0).

pub fn with_speed_priority(self, speed_priority: f32) -> ModelPreferences

Set speed priority (0.0 to 1.0).

pub fn with_intelligence_priority( self, intelligence_priority: f32, ) -> ModelPreferences

Set intelligence priority (0.0 to 1.0).