#[non_exhaustive]pub struct ResourcesCapability {
pub subscribe: Option<bool>,
pub list_changed: Option<bool>,
}Available on crate features
mcp and tools only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subscribe: Option<bool>list_changed: Option<bool>Trait Implementations
Sourceimpl Clone for ResourcesCapability
impl Clone for ResourcesCapability
Sourcefn clone(&self) -> ResourcesCapability
fn clone(&self) -> ResourcesCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourcesCapability
impl Debug for ResourcesCapability
Sourceimpl Default for ResourcesCapability
impl Default for ResourcesCapability
Sourcefn default() -> ResourcesCapability
fn default() -> ResourcesCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResourcesCapability
impl<'de> Deserialize<'de> for ResourcesCapability
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ResourcesCapability, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ResourcesCapability, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourcesCapability
impl JsonSchema for ResourcesCapability
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResourcesCapability
impl PartialEq for ResourcesCapability
Sourceimpl Serialize for ResourcesCapability
impl Serialize for ResourcesCapability
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ResourcesCapability