ErrorData

Struct ErrorData 

pub struct ErrorData {
    pub code: ErrorCode,
    pub message: Cow<'static, str>,
    pub data: Option<Value>,
}
Available on crate features mcp and tools only.
Error information for JSON-RPC error responses.

This structure follows the JSON-RPC 2.0 specification for error reporting, providing a standardized way to communicate errors between clients and servers.

Fields

code: ErrorCode

The error type that occurred (using standard JSON-RPC error codes)

message: Cow<'static, str>

A short description of the error. The message SHOULD be limited to a concise single sentence.

data: Option<Value>

Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.).

Implementations

Source

impl ErrorData

pub fn new( code: ErrorCode, message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData

pub fn resource_not_found( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData

Resource-not-found error (-32002). The server upgrades this to INVALID_PARAMS (-32602) for peers negotiating protocol 2026-07-28 or newer (SEP-2164).

pub fn header_mismatch( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData

pub fn unsupported_protocol_version( requested: ProtocolVersion, supported: &[ProtocolVersion], ) -> ErrorData

Create an unsupported-protocol-version error.

pub fn missing_required_client_capability( required: ClientCapabilities, ) -> ErrorData

Create a missing-required-capability error.

pub fn parse_error( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData

pub fn invalid_request( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData

pub fn method_not_found<M>() -> ErrorData
where M: ConstString,

pub fn invalid_params( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData

pub fn internal_error( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> ErrorData