#[non_exhaustive]pub struct CompletionContext {
pub arguments: Option<HashMap<String, String>>,
}Available on crate features
mcp and tools only.Expand description
Context for completion requests providing previously resolved arguments.
This enables context-aware completion where subsequent argument completions can take into account the values of previously resolved arguments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arguments: Option<HashMap<String, String>>Previously resolved argument values that can inform completion suggestions
Implementations
Sourceimpl CompletionContext
impl CompletionContext
Sourcepub fn new() -> CompletionContext
pub fn new() -> CompletionContext
Create a new empty completion context
Sourcepub fn with_arguments(arguments: HashMap<String, String>) -> CompletionContext
pub fn with_arguments(arguments: HashMap<String, String>) -> CompletionContext
Create a completion context with the given arguments
Sourcepub fn get_argument(&self, name: &str) -> Option<&String>
pub fn get_argument(&self, name: &str) -> Option<&String>
Get a specific argument value by name
Sourcepub fn has_arguments(&self) -> bool
pub fn has_arguments(&self) -> bool
Check if the context has any arguments
Sourcepub fn argument_names(&self) -> impl Iterator<Item = &str>
pub fn argument_names(&self) -> impl Iterator<Item = &str>
Get all argument names