pub struct BasicToolset { /* private fields */ }Available on crate feature
tools only.Expand description
A simple toolset that wraps a static list of tools with optional filtering.
Implementations
Sourceimpl BasicToolset
impl BasicToolset
Sourcepub fn new(name: impl Into<String>, tools: Vec<Arc<dyn Tool>>) -> BasicToolset
pub fn new(name: impl Into<String>, tools: Vec<Arc<dyn Tool>>) -> BasicToolset
Create a new BasicToolset with the given name and tools.
Sourcepub fn with_predicate(
self,
predicate: Box<dyn Fn(&dyn Tool) -> bool + Send + Sync>,
) -> BasicToolset
pub fn with_predicate( self, predicate: Box<dyn Fn(&dyn Tool) -> bool + Send + Sync>, ) -> BasicToolset
Set a predicate to filter which tools are returned.