FilteredToolset

Struct FilteredToolset 

pub struct FilteredToolset { /* private fields */ }
Available on crate feature tools only.
A toolset wrapper that filters tools from an inner toolset using a predicate.

Works with any Toolset implementation. Tools that do not satisfy the predicate are excluded from the resolved tool list.

Example

use adk_tool::toolset::{FilteredToolset, string_predicate};

let browser = BrowserToolset::new(session);
let filtered = FilteredToolset::new(
    Arc::new(browser),
    string_predicate(vec!["navigate".into(), "click".into()]),
);
// Only "navigate" and "click" tools will be exposed

Implementations

Source

impl FilteredToolset

pub fn new( inner: Arc<dyn Toolset>, predicate: Box<dyn Fn(&dyn Tool) -> bool + Sync + Send>, ) -> FilteredToolset

Wrap inner and keep only tools that satisfy predicate.

pub fn with_name( inner: Arc<dyn Toolset>, predicate: Box<dyn Fn(&dyn Tool) -> bool + Sync + Send>, name: impl Into<String>, ) -> FilteredToolset

Wrap inner with a custom name and keep only tools that satisfy predicate.