GoogleSearchTool

Struct GoogleSearchTool 

pub struct GoogleSearchTool;
Available on crate feature tools only.
GoogleSearch is a built-in tool that is automatically invoked by Gemini models to retrieve search results from Google Search. The tool operates internally within the model and does not require or perform local code execution.

Implementations

Source

impl GoogleSearchTool

pub fn new() -> GoogleSearchTool

Create a new GoogleSearchTool.