#[non_exhaustive]pub struct Resource {
pub uri: String,
pub name: String,
pub title: Option<String>,
pub description: Option<String>,
pub mime_type: Option<String>,
pub size: Option<u64>,
pub icons: Option<Vec<Icon>>,
pub meta: Option<MetaObject>,
pub annotations: Option<Annotations>,
}Available on crate feature
tools only.Expand description
A known resource that the server is capable of reading (spec Resource).
Also used as the inner type of ContentBlock::ResourceLink (spec ResourceLink extends Resource).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringThe URI of this resource (e.g. file:///path/to/file).
name: StringThe programmatic name of the resource.
title: Option<String>Optional human-readable display title.
description: Option<String>Optional description of what this resource represents.
mime_type: Option<String>The MIME type of this resource, if known.
size: Option<u64>The size of the raw resource content in bytes (before base64/tokenization), if known.
icons: Option<Vec<Icon>>Optional set of icons the client may display for this resource.
meta: Option<MetaObject>Optional protocol-level metadata for this resource.
annotations: Option<Annotations>Optional annotations describing how the client should use this resource.
Implementations
Sourceimpl Resource
impl Resource
pub fn new(uri: impl Into<String>, name: impl Into<String>) -> Resource
Available on crate feature
mcp only.pub fn with_title(self, title: impl Into<String>) -> Resource
Available on crate feature
mcp only.pub fn with_description(self, description: impl Into<String>) -> Resource
Available on crate feature
mcp only.pub fn with_mime_type(self, mime_type: impl Into<String>) -> Resource
Available on crate feature
mcp only.pub fn with_size(self, size: u64) -> Resource
Available on crate feature
mcp only.pub fn with_icons(self, icons: Vec<Icon>) -> Resource
Available on crate feature
mcp only.pub fn with_meta(self, meta: MetaObject) -> Resource
Available on crate feature
mcp only.pub fn with_annotations(self, annotations: Annotations) -> Resource
Available on crate feature
mcp only.Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Resource
impl<'de> Deserialize<'de> for Resource
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Resource, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Resource, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Resource
impl JsonSchema for Resource
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for Resource
impl Serialize for Resource
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Resource