pub struct WebSearchTool { /* private fields */ }Available on crate feature
tools only.Expand description
WebSearch is a built-in tool for Anthropic Claude models that enables server-side web search. The model searches the web internally and returns results as ServerToolUse / WebSearchToolResult content blocks.
Implementations
Sourceimpl WebSearchTool
impl WebSearchTool
pub fn new() -> WebSearchTool
pub fn with_allowed_domains( self, domains: impl IntoIterator<Item = impl Into<String>>, ) -> WebSearchTool
pub fn with_blocked_domains( self, domains: impl IntoIterator<Item = impl Into<String>>, ) -> WebSearchTool
pub fn with_max_uses(self, max_uses: i32) -> WebSearchTool
pub fn with_user_location( self, user_location: WebSearchUserLocation, ) -> WebSearchTool