pub struct PrefixedToolset { /* private fields */ }Available on crate feature
tools only.Expand description
A toolset wrapper that prefixes all tool names from an inner toolset.
Useful for namespacing tools when composing multiple toolsets that might have overlapping tool names.
Example
ⓘ
use adk_tool::toolset::PrefixedToolset;
let browser = BrowserToolset::new(session);
let prefixed = PrefixedToolset::new(Arc::new(browser), "browser");
// Tools become "browser_navigate", "browser_click", etc.Implementations