pub trait TeamAgentRegistry: Send + Sync {
// Required methods
fn candidates<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TeamAgentDescriptor>, AdkError>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn resolve<'life0, 'life1, 'async_trait>(
&'life0 self,
binding: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Agent>, AdkError>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
// Provided method
fn authorize<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_member: &'life1 TeamMemberSpec,
_candidate: &'life2 TeamAgentDescriptor,
) -> Pin<Box<dyn Future<Output = Result<bool, AdkError>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait { ... }
}Available on crate feature
agents only.Expand description
Discovers and resolves local or remote agents for portable team members.
Required Methods
Sourcefn candidates<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TeamAgentDescriptor>, AdkError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn candidates<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TeamAgentDescriptor>, AdkError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Lists candidates visible to the current deployment and caller.
Sourcefn resolve<'life0, 'life1, 'async_trait>(
&'life0 self,
binding: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Agent>, AdkError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn resolve<'life0, 'life1, 'async_trait>(
&'life0 self,
binding: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Agent>, AdkError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Resolves one immutable binding identifier to an executable agent.
Provided Methods
Authorizes a candidate for one portable member after metadata filtering.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".