pub enum ContentBlock {
Text(TextBlock),
Image(ImageBlock),
ToolUse(ToolUseBlock),
ServerToolUse(ServerToolUseBlock),
WebSearchToolResult(WebSearchToolResultBlock),
WebFetchToolResult(WebFetchToolResultBlock),
ToolResult(ToolResultBlock),
Document(DocumentBlock),
Thinking(ThinkingBlock),
RedactedThinking(RedactedThinkingBlock),
CodeExecutionResult(CodeExecutionResultBlock),
ProgrammaticToolUse(ProgrammaticToolUseBlock),
}anthropic-client only.Expand description
A block of content in a message.
This enum represents the different types of content blocks that can be included in a message’s content.
Variants
Text(TextBlock)
A block of text content
Image(ImageBlock)
An image block
ToolUse(ToolUseBlock)
A block representing a tool use request
ServerToolUse(ServerToolUseBlock)
A block representing a server-side tool use request
WebSearchToolResult(WebSearchToolResultBlock)
A web search tool result block
WebFetchToolResult(WebFetchToolResultBlock)
A web fetch tool result block
ToolResult(ToolResultBlock)
A tool result block
Document(DocumentBlock)
A document block
Thinking(ThinkingBlock)
A block containing model thinking
RedactedThinking(RedactedThinkingBlock)
A block containing redacted thinking data
CodeExecutionResult(CodeExecutionResultBlock)
A code execution result block
ProgrammaticToolUse(ProgrammaticToolUseBlock)
A programmatic tool use block from code execution
Implementations
Sourceimpl ContentBlock
impl ContentBlock
Sourcepub fn is_tool_use(&self) -> bool
pub fn is_tool_use(&self) -> bool
Returns true if this block is a tool use block
Sourcepub fn is_server_tool_use(&self) -> bool
pub fn is_server_tool_use(&self) -> bool
Returns true if this block is a server tool use block
Sourcepub fn is_web_search_tool_result(&self) -> bool
pub fn is_web_search_tool_result(&self) -> bool
Returns true if this block is a web search tool result block
Sourcepub fn is_web_fetch_tool_result(&self) -> bool
pub fn is_web_fetch_tool_result(&self) -> bool
Returns true if this block is a web fetch tool result block
Sourcepub fn is_tool_result(&self) -> bool
pub fn is_tool_result(&self) -> bool
Returns true if this block is a tool result block
Sourcepub fn is_document(&self) -> bool
pub fn is_document(&self) -> bool
Returns true if this block is a document block
Sourcepub fn is_thinking(&self) -> bool
pub fn is_thinking(&self) -> bool
Returns true if this block is a thinking block
Sourcepub fn is_redacted_thinking(&self) -> bool
pub fn is_redacted_thinking(&self) -> bool
Returns true if this block is a redacted thinking block
Sourcepub fn as_text(&self) -> Option<&TextBlock>
pub fn as_text(&self) -> Option<&TextBlock>
Returns a reference to the inner TextBlock if this is a Text variant, or None otherwise.
Sourcepub fn as_image(&self) -> Option<&ImageBlock>
pub fn as_image(&self) -> Option<&ImageBlock>
Returns a reference to the inner ImageBlock if this is an Image variant, or None otherwise.
Sourcepub fn as_tool_use(&self) -> Option<&ToolUseBlock>
pub fn as_tool_use(&self) -> Option<&ToolUseBlock>
Returns a reference to the inner ToolUseBlock if this is a ToolUse variant, or None otherwise.
Sourcepub fn as_server_tool_use(&self) -> Option<&ServerToolUseBlock>
pub fn as_server_tool_use(&self) -> Option<&ServerToolUseBlock>
Returns a reference to the inner ServerToolUseBlock if this is a ServerToolUse variant, or None otherwise.
Sourcepub fn as_web_search_tool_result(&self) -> Option<&WebSearchToolResultBlock>
pub fn as_web_search_tool_result(&self) -> Option<&WebSearchToolResultBlock>
Returns a reference to the inner WebSearchToolResultBlock if this is a WebSearchToolResult variant, or None otherwise.
Sourcepub fn as_web_fetch_tool_result(&self) -> Option<&WebFetchToolResultBlock>
pub fn as_web_fetch_tool_result(&self) -> Option<&WebFetchToolResultBlock>
Returns a reference to the inner WebFetchToolResultBlock if this is a WebFetchToolResult variant, or None otherwise.
Sourcepub fn as_tool_result(&self) -> Option<&ToolResultBlock>
pub fn as_tool_result(&self) -> Option<&ToolResultBlock>
Returns a reference to the inner ToolResultBlock if this is a ToolResult variant, or None otherwise.
Sourcepub fn as_document(&self) -> Option<&DocumentBlock>
pub fn as_document(&self) -> Option<&DocumentBlock>
Returns a reference to the inner DocumentBlock if this is a Document variant, or None otherwise.
Sourcepub fn as_thinking(&self) -> Option<&ThinkingBlock>
pub fn as_thinking(&self) -> Option<&ThinkingBlock>
Returns a reference to the inner ThinkingBlock if this is a Thinking variant, or None otherwise.
Sourcepub fn as_redacted_thinking(&self) -> Option<&RedactedThinkingBlock>
pub fn as_redacted_thinking(&self) -> Option<&RedactedThinkingBlock>
Returns a reference to the inner RedactedThinkingBlock if this is a RedactedThinking variant, or None otherwise.
Sourcepub fn is_code_execution_result(&self) -> bool
pub fn is_code_execution_result(&self) -> bool
Returns true if this block is a code execution result block
Sourcepub fn as_code_execution_result(&self) -> Option<&CodeExecutionResultBlock>
pub fn as_code_execution_result(&self) -> Option<&CodeExecutionResultBlock>
Returns a reference to the inner CodeExecutionResultBlock if this is a CodeExecutionResult variant, or None otherwise.
Sourcepub fn is_programmatic_tool_use(&self) -> bool
pub fn is_programmatic_tool_use(&self) -> bool
Returns true if this block is a programmatic tool use block
Sourcepub fn as_programmatic_tool_use(&self) -> Option<&ProgrammaticToolUseBlock>
pub fn as_programmatic_tool_use(&self) -> Option<&ProgrammaticToolUseBlock>
Returns a reference to the inner ProgrammaticToolUseBlock if this is a ProgrammaticToolUse variant, or None otherwise.