Error

Enum Error 

pub enum Error {
Show 20 variants Api { status_code: u16, error_type: Option<String>, message: String, request_id: Option<String>, }, Authentication { message: String, }, Permission { message: String, }, NotFound { message: String, resource_type: Option<String>, resource_id: Option<String>, }, RateLimit { message: String, retry_after: Option<u64>, }, BadRequest { message: String, param: Option<String>, }, Timeout { message: String, duration: Option<f64>, }, Abort { message: String, }, Connection { message: String, source: Option<Arc<dyn Error + Send + Sync>>, }, InternalServer { message: String, request_id: Option<String>, }, ServiceUnavailable { message: String, retry_after: Option<u64>, }, Serialization { message: String, source: Option<Arc<dyn Error + Send + Sync>>, }, Io { message: String, source: Arc<Error>, }, HttpClient { message: String, source: Option<Arc<dyn Error + Send + Sync>>, }, Validation { message: String, param: Option<String>, }, Url { message: String, source: Option<ParseError>, }, Streaming { message: String, source: Option<Arc<dyn Error + Send + Sync>>, }, Encoding { message: String, source: Option<Arc<dyn Error + Send + Sync>>, }, Unknown { message: String, }, ToDo { message: String, },
}
Available on crate feature anthropic-client only.
The main error type for the adk-anthropic client.

Variants



Api

A generic API error occurred.

Fields

status_code: u16

HTTP status code.

error_type: Option<String>

Error type string from the API.

message: String

Human-readable error message.

request_id: Option<String>

Request ID for debugging and support.



Authentication

Authentication error.

Fields

message: String

Human-readable error message.



Permission

Authorization/Permission error.

Fields

message: String

Human-readable error message.



NotFound

Resource not found.

Fields

message: String

Human-readable error message.

resource_type: Option<String>

Resource type.

resource_id: Option<String>

Resource ID.



RateLimit

Rate limit exceeded.

Fields

message: String

Human-readable error message.

retry_after: Option<u64>

Time to wait before retrying, in seconds.



BadRequest

Bad request due to invalid parameters.

Fields

message: String

Human-readable error message.

param: Option<String>

Parameter that caused the error.



Timeout

API timeout error.

Fields

message: String

Human-readable error message.

duration: Option<f64>

Duration of the timeout in seconds.



Abort

Request was aborted by the client.

Fields

message: String

Human-readable error message.



Connection

Connection error.

Fields

message: String

Human-readable error message.

source: Option<Arc<dyn Error + Send + Sync>>

Underlying cause.



InternalServer

Server returned a 500 internal error.

Fields

message: String

Human-readable error message.

request_id: Option<String>

Request ID for debugging and support.



ServiceUnavailable

Server is overloaded or unavailable.

Fields

message: String

Human-readable error message.

retry_after: Option<u64>

Time to wait before retrying, in seconds.



Serialization

Error during JSON serialization or deserialization.

Fields

message: String

Human-readable error message.

source: Option<Arc<dyn Error + Send + Sync>>

The underlying error.



Io

I/O error.

Fields

message: String

Human-readable error message.

source: Arc<Error>

The underlying error.



HttpClient

HTTP client error.

Fields

message: String

Human-readable error message.

source: Option<Arc<dyn Error + Send + Sync>>

The underlying error.



Validation

Error during validation of request parameters.

Fields

message: String

Human-readable error message.

param: Option<String>

Parameter that failed validation.



Url

A URL parsing or manipulation error.

Fields

message: String

Human-readable error message.

source: Option<ParseError>

The underlying error.



Streaming

A streaming error occurred.

Fields

message: String

Human-readable error message.

source: Option<Arc<dyn Error + Send + Sync>>

The underlying error.



Encoding

Encoding/decoding error.

Fields

message: String

Human-readable error message.

source: Option<Arc<dyn Error + Send + Sync>>

The underlying error.



Unknown

Unknown error.

Fields

message: String

Human-readable error message.



ToDo

Unimplemented functionality.

Fields

message: String

Human-readable error message.

Implementations

Source

impl Error

pub fn api( status_code: u16, error_type: Option<String>, message: String, request_id: Option<String>, ) -> Error

Creates a new API error.

pub fn authentication(message: impl Into<String>) -> Error

Creates a new authentication error.

pub fn permission(message: impl Into<String>) -> Error

Creates a new permission error.

pub fn not_found( message: impl Into<String>, resource_type: Option<String>, resource_id: Option<String>, ) -> Error

Creates a new not found error.

pub fn rate_limit(message: impl Into<String>, retry_after: Option<u64>) -> Error

Creates a new rate limit error.

pub fn bad_request(message: impl Into<String>, param: Option<String>) -> Error

Creates a new bad request error.

pub fn timeout(message: impl Into<String>, duration: Option<f64>) -> Error

Creates a new timeout error.

pub fn abort(message: impl Into<String>) -> Error

Creates a new abort error.

pub fn connection( message: impl Into<String>, source: Option<Box<dyn Error + Send + Sync>>, ) -> Error

Creates a new connection error.

pub fn internal_server( message: impl Into<String>, request_id: Option<String>, ) -> Error

Creates a new internal server error.

pub fn service_unavailable( message: impl Into<String>, retry_after: Option<u64>, ) -> Error

Creates a new service unavailable error.

pub fn serialization( message: impl Into<String>, source: Option<Box<dyn Error + Send + Sync>>, ) -> Error

Creates a new serialization error.

pub fn io(message: impl Into<String>, source: Error) -> Error

Creates a new I/O error.

pub fn http_client( message: impl Into<String>, source: Option<Box<dyn Error + Send + Sync>>, ) -> Error

Creates a new HTTP client error.

pub fn validation(message: impl Into<String>, param: Option<String>) -> Error

Creates a new validation error.

pub fn url(message: impl Into<String>, source: Option<ParseError>) -> Error

Creates a new URL error.

pub fn streaming( message: impl Into<String>, source: Option<Box<dyn Error + Send + Sync>>, ) -> Error

Creates a new streaming error.

pub fn encoding( message: impl Into<String>, source: Option<Box<dyn Error + Send + Sync>>, ) -> Error

Creates a new encoding error.

pub fn unknown(message: impl Into<String>) -> Error

Creates a new unknown error.

pub fn todo(message: impl Into<String>) -> Error

Creates a new ToDo error for unimplemented functionality.

pub fn is_authentication(&self) -> bool

Returns true if this error is related to authentication.

pub fn is_permission(&self) -> bool

Returns true if this error is related to permissions.

pub fn is_not_found(&self) -> bool

Returns true if this error is a “not found” error.

pub fn is_rate_limit(&self) -> bool

Returns true if this error is related to rate limiting.

pub fn is_bad_request(&self) -> bool

Returns true if this error is a bad request.

pub fn is_timeout(&self) -> bool

Returns true if this error is a timeout.

pub fn is_abort(&self) -> bool

Returns true if this error is an abort.

pub fn is_connection(&self) -> bool

Returns true if this error is a connection error.

pub fn is_server_error(&self) -> bool

Returns true if this error is a server error.

pub fn is_retryable(&self) -> bool

Returns true if this error is retryable.

pub fn is_todo(&self) -> bool

Returns true if this error is a ToDo error.

pub fn is_validation(&self) -> bool

Returns true if this error is a validation error.

pub fn request_id(&self) -> Option<&str>

Returns the request ID associated with this error, if any.

pub fn status_code(&self) -> Option<u16>

Returns the status code associated with this error, if any.