pub enum OutputFormat {
Json,
JsonSchema {
schema: Value,
},
}Available on crate feature
anthropic-client only.Expand description
Output format configuration for structured outputs.
Structured outputs constrain Claude’s responses to follow a specific schema, ensuring valid, parseable output for downstream processing.
This feature requires the beta header structured-outputs-2025-11-13.
Example
use serde_json::json;
use adk_anthropic::OutputFormat;
let output_format = OutputFormat::json_schema(json!({
"type": "object",
"properties": {
"name": { "type": "string" },
"email": { "type": "string" },
"plan_interest": { "type": "string" },
"demo_requested": { "type": "boolean" }
},
"required": ["name", "email", "plan_interest", "demo_requested"],
"additionalProperties": false
}));Variants
Json
JSON object format — {type: "json_object"}.
JsonSchema
JSON schema format for structured outputs.
Claude will return valid JSON matching the provided schema in
response.content[0].text.
Implementations
Sourceimpl OutputFormat
impl OutputFormat
Sourcepub fn json_schema(schema: Value) -> OutputFormat
pub fn json_schema(schema: Value) -> OutputFormat
Create a new JSON schema output format.
Arguments
schema- A JSON schema that defines the structure of the response.
Example
use serde_json::json;
use adk_anthropic::OutputFormat;
let output_format = OutputFormat::json_schema(json!({
"type": "object",
"properties": {
"summary": { "type": "string" },
"confidence": { "type": "number" }
},
"required": ["summary", "confidence"],
"additionalProperties": false
}));Trait Implementations
Sourceimpl Clone for OutputFormat
impl Clone for OutputFormat
Sourcefn clone(&self) -> OutputFormat
fn clone(&self) -> OutputFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputFormat
impl Debug for OutputFormat
Sourceimpl<'de> Deserialize<'de> for OutputFormat
impl<'de> Deserialize<'de> for OutputFormat
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OutputFormat, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OutputFormat, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OutputFormat
impl PartialEq for OutputFormat
Sourceimpl Serialize for OutputFormat
impl Serialize for OutputFormat
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for OutputFormat