pub enum ToolChoice {
Auto {
disable_parallel_tool_use: Option<bool>,
},
Any {
disable_parallel_tool_use: Option<bool>,
},
Tool {
name: String,
disable_parallel_tool_use: Option<bool>,
},
None,
}Available on crate feature
anthropic-client only.Expand description
Configuration for Claude’s tool choice behavior.
This can be one of the following:
- “auto”: Let the model decide if and when to use tools
- “any”: Allow the model to use any available tool
- “tool”: Force the model to use a specific named tool
- “none”: Do not use any tools
Variants
Auto
Automatic tool choice
Fields
Any
Any tool choice
Fields
Tool
Specific tool choice
Fields
None
No tools
Implementations
Sourceimpl ToolChoice
impl ToolChoice
Sourcepub fn auto() -> ToolChoice
pub fn auto() -> ToolChoice
Create a new ToolChoice with auto mode.
Sourcepub fn auto_with_disable_parallel(disable: bool) -> ToolChoice
pub fn auto_with_disable_parallel(disable: bool) -> ToolChoice
Create a new ToolChoice with auto mode, specifying whether to disable parallel tool use.
Sourcepub fn any() -> ToolChoice
pub fn any() -> ToolChoice
Create a new ToolChoice allowing any tool.
Sourcepub fn any_with_disable_parallel(disable: bool) -> ToolChoice
pub fn any_with_disable_parallel(disable: bool) -> ToolChoice
Create a new ToolChoice allowing any tool, specifying whether to disable parallel tool use.
Sourcepub fn tool(name: impl Into<String>) -> ToolChoice
pub fn tool(name: impl Into<String>) -> ToolChoice
Create a new ToolChoice with a specific named tool.
Sourcepub fn tool_with_disable_parallel(
name: impl Into<String>,
disable: bool,
) -> ToolChoice
pub fn tool_with_disable_parallel( name: impl Into<String>, disable: bool, ) -> ToolChoice
Create a new ToolChoice with a specific named tool, specifying whether to disable parallel tool use.
Sourcepub fn none() -> ToolChoice
pub fn none() -> ToolChoice
Create a new ToolChoice with no tools.