ToolUnionParam

Enum ToolUnionParam 

pub enum ToolUnionParam {
    CustomTool(ToolParam),
    Bash20241022(ToolBash20241022),
    Bash20250124(ToolBash20250124),
    TextEditor20250124(ToolTextEditor20250124),
    TextEditor20250429(ToolTextEditor20250429),
    TextEditor20250728(ToolTextEditor20250728),
    WebSearch20250305(WebSearchTool20250305),
    WebFetch20250910(WebFetchTool20250910),
}
Available on crate feature anthropic-client only.
Union type for different tool parameter types.

This type represents a union of different tool types that can be used with Claude, including:

  • Custom tools
  • Bash tools
  • Text editor tools
  • Web search tools

The API accepts any of these tool types when tools are provided to Claude.

Variants



CustomTool(ToolParam)

A custom tool with a defined schema



Bash20241022(ToolBash20241022)

A bash tool for executing shell commands (version 20241022)



Bash20250124(ToolBash20250124)

A bash tool for executing shell commands (version 20250124)



TextEditor20250124(ToolTextEditor20250124)

A text editor tool for making changes to text



TextEditor20250429(ToolTextEditor20250429)

A text editor tool for making changes to text (version 20250429)



TextEditor20250728(ToolTextEditor20250728)

A text editor tool for making changes to text (version 20250728)



WebSearch20250305(WebSearchTool20250305)

A web search tool for retrieving information from the internet



WebFetch20250910(WebFetchTool20250910)

A web fetch tool for fetching the content of a user-provided URL (version 20250910)

Implementations

Source

impl ToolUnionParam

pub fn new_custom_tool(name: String, input_schema: Value) -> ToolUnionParam

Creates a new custom tool

pub fn new_bash_20241022_tool() -> ToolUnionParam

Creates a new bash tool (version 20241022)

pub fn new_bash_tool() -> ToolUnionParam

Creates a new bash tool (version 20250124)

pub fn new_text_editor_tool() -> ToolUnionParam

Creates a new text editor tool

pub fn new_text_editor_20250429_tool() -> ToolUnionParam

Creates a new text editor tool (version 20250429)

pub fn new_text_editor_20250728_tool() -> ToolUnionParam

Creates a new text editor tool (version 20250728)

pub fn new_web_search_tool() -> ToolUnionParam

Creates a new web search tool

pub fn new_web_fetch_tool() -> ToolUnionParam

Creates a new web fetch tool

pub fn is_strict(&self) -> bool

Check if this tool has strict mode enabled.

Only custom tools can have strict mode enabled. All other tool types return false.