pub enum WebSearchErrorCode {
InvalidToolInput,
Unavailable,
MaxUsesExceeded,
TooManyRequests,
QueryTooLong,
}Available on crate feature
anthropic-client only.Expand description
Error codes that can be returned when a web search tool operation fails.
Variants
InvalidToolInput
The input provided to the web search tool is invalid.
The web search service is currently unavailable.
MaxUsesExceeded
The maximum number of uses for the web search tool has been exceeded.
TooManyRequests
Too many requests have been made to the web search service.
QueryTooLong
The query provided to the web search tool is too long.