MessageCountTokensParams

Struct MessageCountTokensParams 

pub struct MessageCountTokensParams {
    pub messages: Vec<MessageParam>,
    pub model: Model,
    pub system: Option<SystemPrompt>,
    pub thinking: Option<ThinkingConfig>,
    pub tool_choice: Option<ToolChoice>,
    pub tools: Option<Vec<ToolUnionParam>>,
}
Available on crate feature anthropic-client only.
Parameters for counting tokens in messages.

Fields

messages: Vec<MessageParam>

Input messages.

Our models are trained to operate on alternating user and assistant conversational turns. When creating a new Message, you specify the prior conversational turns with the messages parameter, and the model then generates the next Message in the conversation. Consecutive user or assistant turns in your request will be combined into a single turn.

Each input message must be an object with a role and content. You can specify a single user-role message, or you can include multiple user and assistant messages.

If the final message uses the assistant role, the response content will continue immediately from the content in that message. This can be used to constrain part of the model’s response.

model: Model

The model that will count tokens.

See models for additional details and options.

system: Option<SystemPrompt>

System prompt.

A system prompt is a way of providing context and instructions to Claude, such as specifying a particular goal or role. See the guide to system prompts.

thinking: Option<ThinkingConfig>

Configuration for enabling Claude’s extended thinking.

When enabled, responses include thinking content blocks showing Claude’s thinking process before the final answer. Requires a minimum budget of 1,024 tokens and counts towards your max_tokens limit.

See extended thinking for details.

tool_choice: Option<ToolChoice>

How the model should use the provided tools.

The model can use a specific tool, any available tool, decide by itself, or not use tools at all.

tools: Option<Vec<ToolUnionParam>>

Definitions of tools that the model may use.

If you include tools in your API request, the model may return tool_use content blocks that represent the model’s use of those tools. You can then run those tools using the tool input generated by the model and then optionally return results back to the model using tool_result content blocks.

Implementations

Source

impl MessageCountTokensParams

pub fn new( messages: Vec<MessageParam>, model: Model, ) -> MessageCountTokensParams

Create a new MessageCountTokensParams with the required fields.

pub fn with_system_string(self, system: String) -> MessageCountTokensParams

Add a system prompt as a string.

pub fn with_system_blocks( self, blocks: Vec<TextBlock>, ) -> MessageCountTokensParams

Add a system prompt as text blocks.

pub fn with_system(self, system: SystemPrompt) -> MessageCountTokensParams

Add a system prompt.

pub fn with_thinking(self, thinking: ThinkingConfig) -> MessageCountTokensParams

Add thinking configuration.

pub fn with_tool_choice( self, tool_choice: ToolChoice, ) -> MessageCountTokensParams

Add tool choice.

pub fn with_tools(self, tools: Vec<ToolUnionParam>) -> MessageCountTokensParams

Add tools.