pub struct TextBlock {
pub citations: Option<Vec<TextCitation>>,
pub text: String,
pub cache_control: Option<CacheControlEphemeral>,
}Available on crate feature
anthropic-client only.Expand description
A block of text content in a message.
TextBlocks contain plain text content and optional citations.
Fields
citations: Option<Vec<TextCitation>>Optional citations supporting the text block.
The type of citation returned will depend on the type of document being cited.
Citing a PDF results in page_location, plain text results in char_location,
and content document results in content_block_location.
text: StringThe text content.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block.
Implementations
Sourceimpl TextBlock
impl TextBlock
Sourcepub fn with_citations<S>(text: S, citations: Vec<TextCitation>) -> TextBlock
pub fn with_citations<S>(text: S, citations: Vec<TextCitation>) -> TextBlock
Creates a new TextBlock with the specified text and citations.
Sourcepub fn with_cache_control(
self,
cache_control: CacheControlEphemeral,
) -> TextBlock
pub fn with_cache_control( self, cache_control: CacheControlEphemeral, ) -> TextBlock
Add a cache control to this text block.
Sourcepub fn with_citation(self, citation: TextCitation) -> TextBlock
pub fn with_citation(self, citation: TextCitation) -> TextBlock
Add a single citation to this text block.
Sourcepub fn citation_count(&self) -> usize
pub fn citation_count(&self) -> usize
Returns the number of citations if any, or 0 if there are none.
Sourcepub fn has_citations(&self) -> bool
pub fn has_citations(&self) -> bool
Returns true if this text block has citations.