pub struct ToolUseBlock {
pub id: String,
pub input: Value,
pub name: String,
pub cache_control: Option<CacheControlEphemeral>,
}Available on crate feature
anthropic-client only.Expand description
A block representing a tool use request from the model.
ToolUseBlocks indicate the model wants to use a specific tool with certain inputs.
Fields
id: StringA unique identifier for this tool use request.
input: ValueThe input data for the tool, can be any valid JSON.
name: StringThe name of the tool being invoked.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block.
Implementations
Sourceimpl ToolUseBlock
impl ToolUseBlock
Sourcepub fn new<S1, S2>(id: S1, name: S2, input: Value) -> ToolUseBlock
pub fn new<S1, S2>(id: S1, name: S2, input: Value) -> ToolUseBlock
Creates a new ToolUseBlock with the specified id, name, and input.
Sourcepub fn with_cache_control(
self,
cache_control: CacheControlEphemeral,
) -> ToolUseBlock
pub fn with_cache_control( self, cache_control: CacheControlEphemeral, ) -> ToolUseBlock
Add a cache control to this tool use block.