pub struct Usage {
pub cache_creation_input_tokens: Option<i32>,
pub cache_read_input_tokens: Option<i32>,
pub input_tokens: i32,
pub output_tokens: i32,
pub server_tool_use: Option<ServerToolUsage>,
pub cache_creation_input_tokens_1h: Option<i32>,
}Available on crate feature
anthropic-client only.Expand description
Usage information for API calls.
Anthropic’s API bills and rate-limits by token counts, as tokens represent the underlying cost to their systems.
Fields
cache_creation_input_tokens: Option<i32>The number of input tokens used to create the cache entry.
cache_read_input_tokens: Option<i32>The number of input tokens read from the cache.
input_tokens: i32The number of input tokens which were used.
output_tokens: i32The number of output tokens which were used.
server_tool_use: Option<ServerToolUsage>The number of server tool requests.
cache_creation_input_tokens_1h: Option<i32>Tokens written to the 1-hour cache tier.
Implementations
Sourceimpl Usage
impl Usage
Sourcepub fn new(input_tokens: i32, output_tokens: i32) -> Usage
pub fn new(input_tokens: i32, output_tokens: i32) -> Usage
Create a new Usage with the given input and output tokens.
Sourcepub fn with_cache_creation_input_tokens(self, tokens: i32) -> Usage
pub fn with_cache_creation_input_tokens(self, tokens: i32) -> Usage
Set the cache creation input tokens.
Sourcepub fn with_cache_read_input_tokens(self, tokens: i32) -> Usage
pub fn with_cache_read_input_tokens(self, tokens: i32) -> Usage
Set the cache read input tokens.
Sourcepub fn with_server_tool_use(self, server_tool_use: ServerToolUsage) -> Usage
pub fn with_server_tool_use(self, server_tool_use: ServerToolUsage) -> Usage
Set the server tool usage.
Sourcepub fn with_cache_creation_input_tokens_1h(self, tokens: i32) -> Usage
pub fn with_cache_creation_input_tokens_1h(self, tokens: i32) -> Usage
Set the 1-hour cache creation input tokens.