AudioFormat

Enum AudioFormat 

pub enum AudioFormat {
    Pcm16,
    Opus,
    Mp3,
    Wav,
    Flac,
    Ogg,
}
Available on crate feature audio only.
Supported audio formats for encode/decode at transport edges.

Variants



Pcm16

Raw PCM-16 LE (internal format, no header).



Opus

Opus codec (not yet implemented).



Mp3

MP3 format.



Wav

WAV (RIFF) format.



Flac

FLAC lossless format.



Ogg

Ogg container format.

Implementations

Source

impl AudioFormat

pub fn supports_encode(&self) -> bool

Returns true if this format has a working encode() implementation.

Currently only Pcm16 and Wav support encoding.

pub fn supports_decode(&self) -> bool

Returns true if this format has a working decode() implementation.

Currently only Pcm16 and Wav support decoding.