Available on crate feature
auth only.Expand description
Authentication and access control.
Manage agent permissions and identity:
Permission- Permission definitionsAccessControl- Access control enforcement
Available with feature: auth
Modules
- scope
- Scope-based access control for tools.
Structs
- Access
Control - Access control for checking permissions.
- Access
Control Builder - Builder for AccessControl.
- Access
Denied - Error returned when access is denied.
- Audit
Event - An audit event.
- Auth
Middleware - A collection of auth utilities for integrating with ADK.
- Context
Scope Resolver - Resolves user scopes from the
user_scopes()method onToolContext. - File
Audit Sink - File-based audit sink that writes JSONL.
- Protected
Tool - A tool wrapper that enforces access control and optionally logs audit events.
- Protected
Tool Dyn - Dynamic version of
ProtectedToolforArc<dyn Tool>. - Role
- A role with a set of allowed and denied permissions.
- Scope
Denied - Error returned when a user lacks required scopes.
- Scope
Guard - Declarative scope enforcement for tools.
- Scoped
Tool - A tool wrapper that enforces scope requirements before execution.
- Scoped
Tool Dyn - Dynamic version of
ScopedToolforArc<dyn Tool>. - Static
Scope Resolver - A static resolver that always returns a fixed set of scopes.
Enums
- Audit
Event Type - Type of audit event.
- Audit
Outcome - Outcome of an audit event.
- Auth
Error - General auth error.
- Permission
- Permission for accessing tools or agents.
Traits
- Audit
Sink - Trait for audit sinks.
- Scope
Resolver - Resolves the set of scopes granted to the current user.
- Scope
Tool Ext - Extension trait for easily wrapping tools with scope enforcement.
- ToolExt
- Extension trait for easily wrapping tools with access control.
Functions
- check_
scopes - Checks whether a user’s scopes satisfy a tool’s requirements.