pub struct Role {
pub name: String,
/* private fields */
}Available on crate feature
auth only.Expand description
A role with a set of allowed and denied permissions.
Deny rules take precedence over allow rules.
Fields
name: StringRole name (e.g., “admin”, “user”, “analyst”).
Implementations
Sourceimpl Role
impl Role
Sourcepub fn allow(self, permission: Permission) -> Role
pub fn allow(self, permission: Permission) -> Role
Allow a permission for this role.
Sourcepub fn deny(self, permission: Permission) -> Role
pub fn deny(self, permission: Permission) -> Role
Deny a permission for this role.
Deny rules take precedence over allow rules.
Sourcepub fn can_access(&self, permission: &Permission) -> bool
pub fn can_access(&self, permission: &Permission) -> bool
Check if this role can access the given permission.
Returns true if the permission is allowed and not denied.
Deny rules take precedence over allow rules.
Sourcepub fn allowed_permissions(&self) -> &HashSet<Permission>
pub fn allowed_permissions(&self) -> &HashSet<Permission>
Get all allowed permissions.
Sourcepub fn denied_permissions(&self) -> &HashSet<Permission>
pub fn denied_permissions(&self) -> &HashSet<Permission>
Get all denied permissions.