pub trait CollaborationReceiver: Send {
// Required method
fn recv<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Option<CollaborationEvent>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
}Available on crate feature
code only.Expand description
Async trait for receiving collaboration events from a transport.
Each receiver gets its own independent stream of events published after the subscription was created.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".