Available on crate feature
models only.Expand description
Model integrations (Gemini, etc.).
Provides LLM implementations:
GeminiModel- Google’s Gemini models
ADK is model-agnostic - implement the Llm trait for other providers.
Available with feature: models
Modules
- anthropic
anthropic - Anthropic/Claude provider implementation for ADK.
- gemini
gemini - mock
- openai
openai - OpenAI provider implementation for ADK.
- openai_
compatible openai - Shared OpenAI-compatible provider implementation.
- provider
- retry
- tool_
call_ parser - Text-based tool call parser for models that emit tool calls as text tags.
- usage_
tracking - Stream wrapper that records token usage on the active tracing span.
Structs
- Anthropic
Client - Anthropic client for Claude models.
- Azure
Config - Configuration for Azure OpenAI Service.
- Azure
OpenAI Client - Azure OpenAI client.
- Gemini
Model - MockLlm
- OpenAI
Client - OpenAI client for standard OpenAI API and OpenAI-compatible APIs.
- OpenAI
Compatible - Shared OpenAI-compatible client implementation.
- OpenAI
Compatible Config - Configuration for OpenAI-compatible providers.
- OpenAI
Config - Configuration for OpenAI API.
- Retry
Config - Server
Retry Hint - Hint from the server about when to retry.
Enums
- Model
Provider - Canonical provider identifiers and metadata shared across ADK crates.
- Reasoning
Effort - Reasoning effort level for OpenAI reasoning models (e.g., o1, o3).