Plugin

Struct Plugin 

pub struct Plugin { /* private fields */ }
Available on crate feature plugin only.
A Plugin bundles related callbacks for extending agent behavior.

Plugins are registered with a PluginManager which coordinates callback execution across all registered plugins.

Example

use adk_plugin::{Plugin, PluginConfig};

// Create a caching plugin
let cache_plugin = Plugin::new(PluginConfig {
    name: "cache".to_string(),
    before_model: Some(Box::new(|ctx, request| {
        Box::pin(async move {
            // Check cache for this request
            if let Some(cached) = check_cache(&request).await {
                return Ok(BeforeModelResult::Skip(cached));
            }
            Ok(BeforeModelResult::Continue(request))
        })
    })),
    after_model: Some(Box::new(|ctx, response| {
        Box::pin(async move {
            // Store response in cache
            store_in_cache(&response).await;
            Ok(None)
        })
    })),
    ..Default::default()
});

Implementations

Source

impl Plugin

pub fn new(config: PluginConfig) -> Plugin

Create a new plugin from configuration.

pub fn name(&self) -> &str

Get the plugin name.

pub fn on_user_message( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>, Content) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Send + Sync>>

Get the on_user_message callback if set.

pub fn on_event( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>, Event) -> Pin<Box<dyn Future<Output = Result<Option<Event>, AdkError>> + Send>> + Send + Sync>>

Get the on_event callback if set.

pub fn before_run( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Send + Sync>>

Get the before_run callback if set.

pub fn after_run( &self, ) -> Option<&Box<dyn Fn(Arc<dyn InvocationContext>) -> Pin<Box<dyn Future<Output = ()> + Send>> + Send + Sync>>

Get the after_run callback if set.

pub fn before_agent( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Send + Sync>>

Get the before_agent callback if set.

pub fn after_agent( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Send + Sync>>

Get the after_agent callback if set.

pub fn before_model( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmRequest) -> Pin<Box<dyn Future<Output = Result<BeforeModelResult, AdkError>> + Send>> + Send + Sync>>

Get the before_model callback if set.

pub fn after_model( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmResponse) -> Pin<Box<dyn Future<Output = Result<Option<LlmResponse>, AdkError>> + Send>> + Send + Sync>>

Get the after_model callback if set.

pub fn on_model_error( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, LlmRequest, String) -> Pin<Box<dyn Future<Output = Result<Option<LlmResponse>, AdkError>> + Send>> + Send + Sync>>

Get the on_model_error callback if set.

pub fn before_tool( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Send + Sync>>

Get the before_tool callback if set.

pub fn after_tool( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>) -> Pin<Box<dyn Future<Output = Result<Option<Content>, AdkError>> + Send>> + Send + Sync>>

Get the after_tool callback if set.

pub fn on_tool_error( &self, ) -> Option<&Box<dyn Fn(Arc<dyn CallbackContext>, Arc<dyn Tool>, Value, String) -> Pin<Box<dyn Future<Output = Result<Option<Value>, AdkError>> + Send>> + Send + Sync>>

Get the on_tool_error callback if set.

pub async fn close(&self)

Close the plugin, running cleanup if configured.