#[non_exhaustive]pub struct FormElicitationCapability {
pub schema_validation: Option<bool>,
}Available on crate features
mcp and tools only.Expand description
Capability for handling elicitation requests from servers. Elicitation allows servers to request interactive input from users during tool execution. This capability indicates that a client can handle elicitation requests and present appropriate UI to users for collecting the requested information.
Capability for form mode elicitation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema_validation: Option<bool>Whether the client supports JSON Schema validation for elicitation responses. When true, the client will validate user input against the requested_schema before sending the response back to the server.
Implementations
Sourceimpl FormElicitationCapability
impl FormElicitationCapability
pub fn new() -> FormElicitationCapability
pub fn with_schema_validation(self, enabled: bool) -> FormElicitationCapability