#[non_exhaustive]pub struct InitializeResult {
pub protocol_version: ProtocolVersion,
pub capabilities: ServerCapabilities,
pub server_info: Implementation,
pub instructions: Option<String>,
pub meta: Option<MetaObject>,
}Available on crate features
mcp and tools only.Expand description
The server’s response to an initialization request.
Contains the server’s protocol version, capabilities, and implementation information, along with optional instructions for the client.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.protocol_version: ProtocolVersionThe MCP protocol version this server supports
capabilities: ServerCapabilitiesThe capabilities this server provides (tools, resources, prompts, etc.)
server_info: ImplementationInformation about the server implementation
instructions: Option<String>Optional human-readable instructions about using this server
meta: Option<MetaObject>Implementations
Sourceimpl InitializeResult
impl InitializeResult
Sourcepub fn new(capabilities: ServerCapabilities) -> InitializeResult
pub fn new(capabilities: ServerCapabilities) -> InitializeResult
Create a new InitializeResult with default protocol version and the given capabilities.
Sourcepub fn with_instructions(
self,
instructions: impl Into<String>,
) -> InitializeResult
pub fn with_instructions( self, instructions: impl Into<String>, ) -> InitializeResult
Set instructions on this result.
Sourcepub fn with_server_info(self, server_info: Implementation) -> InitializeResult
pub fn with_server_info(self, server_info: Implementation) -> InitializeResult
Set the server info on this result.
Sourcepub fn with_protocol_version(
self,
protocol_version: ProtocolVersion,
) -> InitializeResult
pub fn with_protocol_version( self, protocol_version: ProtocolVersion, ) -> InitializeResult
Set the protocol version on this result.