#[non_exhaustive]pub struct ModelPreferences {
pub hints: Option<Vec<ModelHint>>,
pub cost_priority: Option<f32>,
pub speed_priority: Option<f32>,
pub intelligence_priority: Option<f32>,
}Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
mcp and tools only.Expand description
Preferences for model selection and behavior in sampling requests.
This allows servers to express their preferences for which model to use and how to balance different priorities when the client has multiple model options available.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hints: Option<Vec<ModelHint>>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Specific model names or families to prefer (e.g., โclaudeโ, โgptโ)
cost_priority: Option<f32>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Priority for cost optimization (0.0 to 1.0, higher = prefer cheaper models)
speed_priority: Option<f32>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Priority for speed/latency (0.0 to 1.0, higher = prefer faster models)
intelligence_priority: Option<f32>Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577
Priority for intelligence/capability (0.0 to 1.0, higher = prefer more capable models)
Implementations
Sourceimpl ModelPreferences
impl ModelPreferences
Sourcepub fn new() -> ModelPreferences
pub fn new() -> ModelPreferences
Create a new default ModelPreferences.
Sourcepub fn with_hints(self, hints: Vec<ModelHint>) -> ModelPreferences
pub fn with_hints(self, hints: Vec<ModelHint>) -> ModelPreferences
Set hints for model selection.
Sourcepub fn with_cost_priority(self, cost_priority: f32) -> ModelPreferences
pub fn with_cost_priority(self, cost_priority: f32) -> ModelPreferences
Set cost priority (0.0 to 1.0).
Sourcepub fn with_speed_priority(self, speed_priority: f32) -> ModelPreferences
pub fn with_speed_priority(self, speed_priority: f32) -> ModelPreferences
Set speed priority (0.0 to 1.0).
Sourcepub fn with_intelligence_priority(
self,
intelligence_priority: f32,
) -> ModelPreferences
pub fn with_intelligence_priority( self, intelligence_priority: f32, ) -> ModelPreferences
Set intelligence priority (0.0 to 1.0).