pub struct UrlContextTool;Available on crate feature
tools only.Expand description
UrlContext is a built-in tool that is automatically invoked by Gemini models to fetch and analyze content from URLs. The tool operates internally within the model and does not require or perform local code execution.
Implementations
Sourceimpl UrlContextTool
impl UrlContextTool
pub fn new() -> UrlContextTool